"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___GetTestRequest = GetTestRequest

@typing.final
class UpdateTestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TEST_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    FAVORITE_FIELD_NUMBER: builtins.int
    TARGET_VERSION_FIELD_NUMBER: builtins.int
    IMBALANCE_POINT_FIELD_NUMBER: builtins.int
    IMBALANCE_TS_FIELD_NUMBER: builtins.int
    IMBALANCE_COMMENT_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    name: builtins.str
    description: builtins.str
    favorite: builtins.bool
    target_version: builtins.str
    imbalance_point: builtins.int
    imbalance_ts: builtins.int
    imbalance_comment: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        favorite: builtins.bool = ...,
        target_version: builtins.str = ...,
        imbalance_point: builtins.int = ...,
        imbalance_ts: builtins.int = ...,
        imbalance_comment: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "favorite", b"favorite", "imbalance_comment", b"imbalance_comment", "imbalance_point", b"imbalance_point", "imbalance_ts", b"imbalance_ts", "labels", b"labels", "name", b"name", "target_version", b"target_version", "test_id", b"test_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateTestRequest = UpdateTestRequest

@typing.final
class UpdateTestMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["test_id", b"test_id"]) -> None: ...

global___UpdateTestMetadata = UpdateTestMetadata
