# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/mysql.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/datatransfer/v1/endpoint/mysql.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"\x8e\x01\n\x0eOnPremiseMysql\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\x12\r\n\x05hosts\x18\x05 \x03(\t\x12@\n\x08tls_mode\x18\x06 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSModeJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04\"\x86\x01\n\x0fMysqlConnection\x12\x18\n\x0emdb_cluster_id\x18\x01 \x01(\tH\x00\x12K\n\non_premise\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.OnPremiseMysqlH\x00\x42\x0c\n\nconnection\"\xcd\x02\n\x1bMysqlObjectTransferSettings\x12H\n\x04view\x18\x01 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12K\n\x07routine\x18\x02 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12K\n\x07trigger\x18\x03 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12J\n\x06tables\x18\x04 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\"\xad\x03\n\x0bMysqlSource\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MysqlConnection\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x64\n\x18object_transfer_settings\x18\x0b \x01(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.MysqlObjectTransferSettings\x12\x1c\n\x14include_tables_regex\x18\x0c \x03(\t\x12\x1c\n\x14\x65xclude_tables_regex\x18\r \x03(\t\x12\x17\n\x0fsecurity_groups\x18\x0e \x03(\t\x12\x18\n\x10service_database\x18\x0f \x01(\tJ\x04\x08\x05\x10\x08J\x04\x08\t\x10\x0b\"\x85\x03\n\x0bMysqlTarget\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MysqlConnection\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x10\n\x08sql_mode\x18\x05 \x01(\t\x12\x1e\n\x16skip_constraint_checks\x18\x06 \x01(\x08\x12\x10\n\x08timezone\x18\x07 \x01(\t\x12L\n\x0e\x63leanup_policy\x18\x08 \x01(\x0e\x32\x34.yandex.cloud.datatransfer.v1.endpoint.CleanupPolicy\x12\x18\n\x10service_database\x18\x0f \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x10 \x03(\tJ\x04\x08\t\x10\x0f\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.mysql_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_ONPREMISEMYSQL']._serialized_start=145
  _globals['_ONPREMISEMYSQL']._serialized_end=287
  _globals['_MYSQLCONNECTION']._serialized_start=290
  _globals['_MYSQLCONNECTION']._serialized_end=424
  _globals['_MYSQLOBJECTTRANSFERSETTINGS']._serialized_start=427
  _globals['_MYSQLOBJECTTRANSFERSETTINGS']._serialized_end=760
  _globals['_MYSQLSOURCE']._serialized_start=763
  _globals['_MYSQLSOURCE']._serialized_end=1192
  _globals['_MYSQLTARGET']._serialized_start=1195
  _globals['_MYSQLTARGET']._serialized_end=1584
# @@protoc_insertion_point(module_scope)
