"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ActivateProviderRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SKIP_DEFAULT_POLICY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Activate provider for Folder iD."""
    name: builtins.str
    """Activate specific provider by name.

    For more information, please see [activate-provider](/docs/backup/quickstart#activate-provider)
    """
    skip_default_policy: builtins.bool
    """Don't create default policies while activating the provider."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        skip_default_policy: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "name", b"name", "skip_default_policy", b"skip_default_policy"]) -> None: ...

global___ActivateProviderRequest = ActivateProviderRequest

@typing.final
class ActivateProviderMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Activate provider for folder specified by ID."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ActivateProviderMetadata = ActivateProviderMetadata

@typing.final
class ListActivatedProvidersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to find out the backup provider."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___ListActivatedProvidersRequest = ListActivatedProvidersRequest

@typing.final
class ListActivatedProvidersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID."""
    @property
    def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Name of the backup provider."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "names", b"names"]) -> None: ...

global___ListActivatedProvidersResponse = ListActivatedProvidersResponse
