"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Manifest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ManifestType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ManifestTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Manifest._ManifestType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MANIFEST_TYPE_UNSPECIFIED: Manifest._ManifestType.ValueType  # 0
        DASH: Manifest._ManifestType.ValueType  # 1
        HLS: Manifest._ManifestType.ValueType  # 2

    class ManifestType(_ManifestType, metaclass=_ManifestTypeEnumTypeWrapper): ...
    MANIFEST_TYPE_UNSPECIFIED: Manifest.ManifestType.ValueType  # 0
    DASH: Manifest.ManifestType.ValueType  # 1
    HLS: Manifest.ManifestType.ValueType  # 2

    URL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    url: builtins.str
    type: global___Manifest.ManifestType.ValueType
    def __init__(
        self,
        *,
        url: builtins.str = ...,
        type: global___Manifest.ManifestType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["type", b"type", "url", b"url"]) -> None: ...

global___Manifest = Manifest
