# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/postgresql/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/mdb/postgresql/v1/user.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xa6\x03\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.Permission\x12\x12\n\nconn_limit\x18\x04 \x01(\x03\x12>\n\x08settings\x18\x05 \x01(\x0b\x32,.yandex.cloud.mdb.postgresql.v1.UserSettings\x12)\n\x05login\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x06grants\x18\x07 \x03(\tB\x19\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x37\n\x13\x64\x65letion_protection\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12X\n\x18user_password_encryption\x18\t \x01(\x0e\x32\x36.yandex.cloud.mdb.postgresql.v1.UserPasswordEncryption\"#\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\"\xfe\x03\n\x08UserSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12?\n\x0bpermissions\x18\x03 \x03(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.Permission\x12\x39\n\nconn_limit\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=10\x12>\n\x08settings\x18\x05 \x01(\x0b\x32,.yandex.cloud.mdb.postgresql.v1.UserSettings\x12)\n\x05login\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12)\n\x06grants\x18\x07 \x03(\tB\x19\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x37\n\x13\x64\x65letion_protection\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12X\n\x18user_password_encryption\x18\t \x01(\x0e\x32\x36.yandex.cloud.mdb.postgresql.v1.UserPasswordEncryption\"\x88\x03\n\x0fPGAuditSettings\x12O\n\x03log\x18\x01 \x03(\x0e\x32\x42.yandex.cloud.mdb.postgresql.v1.PGAuditSettings.PGAuditSettingsLog\"\xa3\x02\n\x12PGAuditSettingsLog\x12%\n!PG_AUDIT_SETTINGS_LOG_UNSPECIFIED\x10\x00\x12\x1e\n\x1aPG_AUDIT_SETTINGS_LOG_READ\x10\x01\x12\x1f\n\x1bPG_AUDIT_SETTINGS_LOG_WRITE\x10\x02\x12\"\n\x1ePG_AUDIT_SETTINGS_LOG_FUNCTION\x10\x03\x12\x1e\n\x1aPG_AUDIT_SETTINGS_LOG_ROLE\x10\x04\x12\x1d\n\x19PG_AUDIT_SETTINGS_LOG_DDL\x10\x05\x12\x1e\n\x1aPG_AUDIT_SETTINGS_LOG_MISC\x10\x06\x12\"\n\x1ePG_AUDIT_SETTINGS_LOG_MISC_SET\x10\x07\"\xcc\x0c\n\x0cUserSettings\x12h\n\x1d\x64\x65\x66\x61ult_transaction_isolation\x18\x01 \x01(\x0e\x32\x41.yandex.cloud.mdb.postgresql.v1.UserSettings.TransactionIsolation\x12\x31\n\x0clock_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1alog_min_duration_statement\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12Z\n\x12synchronous_commit\x18\x04 \x01(\x0e\x32>.yandex.cloud.mdb.postgresql.v1.UserSettings.SynchronousCommit\x12\x34\n\x0ftemp_file_limit\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12P\n\rlog_statement\x18\x06 \x01(\x0e\x32\x39.yandex.cloud.mdb.postgresql.v1.UserSettings.LogStatement\x12K\n\tpool_mode\x18\x07 \x01(\x0e\x32\x38.yandex.cloud.mdb.postgresql.v1.UserSettings.PoolingMode\x12?\n\x1bprepared_statements_pooling\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x0f\x63\x61tchup_timeout\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12wal_sender_timeout\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12Z\n#idle_in_transaction_session_timeout\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-2147483647\x12\x36\n\x11statement_timeout\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x07pgaudit\x18\r \x01(\x0b\x32/.yandex.cloud.mdb.postgresql.v1.PGAuditSettings\"\xd6\x01\n\x11SynchronousCommit\x12\"\n\x1eSYNCHRONOUS_COMMIT_UNSPECIFIED\x10\x00\x12\x19\n\x15SYNCHRONOUS_COMMIT_ON\x10\x01\x12\x1a\n\x16SYNCHRONOUS_COMMIT_OFF\x10\x02\x12\x1c\n\x18SYNCHRONOUS_COMMIT_LOCAL\x10\x03\x12#\n\x1fSYNCHRONOUS_COMMIT_REMOTE_WRITE\x10\x04\x12#\n\x1fSYNCHRONOUS_COMMIT_REMOTE_APPLY\x10\x05\"\x8a\x01\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x16\n\x12LOG_STATEMENT_NONE\x10\x01\x12\x15\n\x11LOG_STATEMENT_DDL\x10\x02\x12\x15\n\x11LOG_STATEMENT_MOD\x10\x03\x12\x15\n\x11LOG_STATEMENT_ALL\x10\x04\"\xe6\x01\n\x14TransactionIsolation\x12%\n!TRANSACTION_ISOLATION_UNSPECIFIED\x10\x00\x12*\n&TRANSACTION_ISOLATION_READ_UNCOMMITTED\x10\x01\x12(\n$TRANSACTION_ISOLATION_READ_COMMITTED\x10\x02\x12)\n%TRANSACTION_ISOLATION_REPEATABLE_READ\x10\x03\x12&\n\"TRANSACTION_ISOLATION_SERIALIZABLE\x10\x04\"X\n\x0bPoolingMode\x12\x1c\n\x18POOLING_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\x12\r\n\tSTATEMENT\x10\x03*\x90\x01\n\x16UserPasswordEncryption\x12(\n$USER_PASSWORD_ENCRYPTION_UNSPECIFIED\x10\x00\x12 \n\x1cUSER_PASSWORD_ENCRYPTION_MD5\x10\x01\x12*\n&USER_PASSWORD_ENCRYPTION_SCRAM_SHA_256\x10\x02\x42s\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _USER.fields_by_name['grants']._options = None
  _USER.fields_by_name['grants']._serialized_options = b'\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _USERSPEC.fields_by_name['name']._options = None
  _USERSPEC.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _USERSPEC.fields_by_name['password']._options = None
  _USERSPEC.fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _USERSPEC.fields_by_name['conn_limit']._options = None
  _USERSPEC.fields_by_name['conn_limit']._serialized_options = b'\372\3071\004>=10'
  _USERSPEC.fields_by_name['grants']._options = None
  _USERSPEC.fields_by_name['grants']._serialized_options = b'\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _USERSETTINGS.fields_by_name['idle_in_transaction_session_timeout']._options = None
  _USERSETTINGS.fields_by_name['idle_in_transaction_session_timeout']._serialized_options = b'\372\3071\0140-2147483647'
  _globals['_USERPASSWORDENCRYPTION']._serialized_start=3126
  _globals['_USERPASSWORDENCRYPTION']._serialized_end=3270
  _globals['_USER']._serialized_start=141
  _globals['_USER']._serialized_end=563
  _globals['_PERMISSION']._serialized_start=565
  _globals['_PERMISSION']._serialized_end=600
  _globals['_USERSPEC']._serialized_start=603
  _globals['_USERSPEC']._serialized_end=1113
  _globals['_PGAUDITSETTINGS']._serialized_start=1116
  _globals['_PGAUDITSETTINGS']._serialized_end=1508
  _globals['_PGAUDITSETTINGS_PGAUDITSETTINGSLOG']._serialized_start=1217
  _globals['_PGAUDITSETTINGS_PGAUDITSETTINGSLOG']._serialized_end=1508
  _globals['_USERSETTINGS']._serialized_start=1511
  _globals['_USERSETTINGS']._serialized_end=3123
  _globals['_USERSETTINGS_SYNCHRONOUSCOMMIT']._serialized_start=2445
  _globals['_USERSETTINGS_SYNCHRONOUSCOMMIT']._serialized_end=2659
  _globals['_USERSETTINGS_LOGSTATEMENT']._serialized_start=2662
  _globals['_USERSETTINGS_LOGSTATEMENT']._serialized_end=2800
  _globals['_USERSETTINGS_TRANSACTIONISOLATION']._serialized_start=2803
  _globals['_USERSETTINGS_TRANSACTIONISOLATION']._serialized_end=3033
  _globals['_USERSETTINGS_POOLINGMODE']._serialized_start=3035
  _globals['_USERSETTINGS_POOLINGMODE']._serialized_end=3123
# @@protoc_insertion_point(module_scope)
