# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tuning/v1/tuning_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.ai.tuning.v1 import tuning_task_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__task__pb2
from yandex.cloud.ai.tuning.v1 import tuning_types_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__types__pb2
from yandex.cloud.ai.tuning.v1 import tuning_optimizers_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__optimizers__pb2
from yandex.cloud.ai.tuning.v1 import tuning_schedulers_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__schedulers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/ai/tuning/v1/tuning_service.proto\x12\x19yandex.cloud.ai.tuning.v1\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a+yandex/cloud/ai/tuning/v1/tuning_task.proto\x1a,yandex/cloud/ai/tuning/v1/tuning_types.proto\x1a\x31yandex/cloud/ai/tuning/v1/tuning_optimizers.proto\x1a\x31yandex/cloud/ai/tuning/v1/tuning_schedulers.proto\"T\n\x12ListTuningsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"k\n\x13ListTuningsResponse\x12;\n\x0ctuning_tasks\x18\x01 \x03(\x0b\x32%.yandex.cloud.ai.tuning.v1.TuningTask\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x15\x44\x65scribeTuningRequest\x12\x1c\n\x0etuning_task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"T\n\x16\x44\x65scribeTuningResponse\x12:\n\x0btuning_task\x18\x01 \x01(\x0b\x32%.yandex.cloud.ai.tuning.v1.TuningTask\"3\n\x13\x43\x61ncelTuningRequest\x12\x1c\n\x0etuning_task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\".\n\x14\x43\x61ncelTuningResponse\x12\x16\n\x0etuning_task_id\x18\x01 \x01(\t\"\x8c\x01\n\x0eTuningResponse\x12\x16\n\x0etuning_task_id\x18\x03 \x01(\t\x12<\n\x06status\x18\x04 \x01(\x0e\x32,.yandex.cloud.ai.tuning.v1.TuningTask.Status\x12\x18\n\x10target_model_uri\x18\x05 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"f\n\x0eTuningMetadata\x12\x16\n\x0etuning_task_id\x18\x01 \x01(\t\x12<\n\x06status\x18\x02 \x01(\x0e\x32,.yandex.cloud.ai.tuning.v1.TuningTask.Status\"\x86\x06\n\rTuningRequest\x12\x1c\n\x0e\x62\x61se_model_uri\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12X\n\x0etrain_datasets\x18\x02 \x03(\x0b\x32\x38.yandex.cloud.ai.tuning.v1.TuningRequest.WeightedDatasetB\x06\x82\xc8\x31\x02>0\x12U\n\x13validation_datasets\x18\x03 \x03(\x0b\x32\x38.yandex.cloud.ai.tuning.v1.TuningRequest.WeightedDataset\x12^\n\x17text_to_text_completion\x18\x64 \x01(\x0b\x32;.yandex.cloud.ai.tuning.v1.TextToTextCompletionTuningParamsH\x00\x12g\n\x1etext_classification_multilabel\x18\x65 \x01(\x0b\x32=.yandex.cloud.ai.tuning.v1.TextClassificationMultilabelParamsH\x00\x12g\n\x1etext_classification_multiclass\x18\x66 \x01(\x0b\x32=.yandex.cloud.ai.tuning.v1.TextClassificationMulticlassParamsH\x00\x12\r\n\x04name\x18\xc8\x01 \x01(\t\x12\x14\n\x0b\x64\x65scription\x18\xc9\x01 \x01(\t\x12\x45\n\x06labels\x18\xca\x01 \x03(\x0b\x32\x34.yandex.cloud.ai.tuning.v1.TuningRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a;\n\x0fWeightedDataset\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x42\x0f\n\rtuning_paramsJ\x04\x08\x04\x10\x64J\x05\x08g\x10\xc8\x01\"\x89\x06\n TextToTextCompletionTuningParams\x12\x0c\n\x04seed\x18\x01 \x01(\x03\x12\n\n\x02lr\x18\x02 \x01(\x01\x12\x11\n\tn_samples\x18\x03 \x01(\x03\x12\x1c\n\x14\x61\x64\x64itional_arguments\x18\x07 \x01(\t\x12\x39\n\x04lora\x18\x64 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.TuningTypeLoraH\x00\x12\x46\n\x0bprompt_tune\x18\x65 \x01(\x0b\x32/.yandex.cloud.ai.tuning.v1.TuningTypePromptTuneH\x00\x12Y\n\tscheduler\x18\xc8\x01 \x01(\x0b\x32\x45.yandex.cloud.ai.tuning.v1.TextToTextCompletionTuningParams.Scheduler\x12Y\n\toptimizer\x18\xc9\x01 \x01(\x0b\x32\x45.yandex.cloud.ai.tuning.v1.TextToTextCompletionTuningParams.Optimizer\x1a\xed\x01\n\tScheduler\x12<\n\x06linear\x18\x01 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerLinearH\x00\x12@\n\x08\x63onstant\x18\x02 \x01(\x0b\x32,.yandex.cloud.ai.tuning.v1.SchedulerConstantH\x00\x12<\n\x06\x63osine\x18\x03 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerCosineH\x00\x12\x14\n\x0cwarmup_ratio\x18\x65 \x01(\x01\x42\x06\n\x04typeJ\x04\x08\x04\x10\x65\x1aO\n\tOptimizer\x12:\n\x05\x61\x64\x61mw\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.OptimizerAdamwH\x00\x42\x06\n\x04typeB\r\n\x0btuning_typeJ\x04\x08\x04\x10\x07J\x04\x08\x08\x10\x64J\x05\x08\x66\x10\xc8\x01\"\x8f\x06\n\"TextClassificationMultilabelParams\x12\x0c\n\x04seed\x18\x01 \x01(\x03\x12\n\n\x02lr\x18\x02 \x01(\x01\x12\x11\n\tn_samples\x18\x03 \x01(\x03\x12\x1c\n\x14\x61\x64\x64itional_arguments\x18\x07 \x01(\t\x12\x39\n\x04lora\x18\x64 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.TuningTypeLoraH\x00\x12\x46\n\x0bprompt_tune\x18\x65 \x01(\x0b\x32/.yandex.cloud.ai.tuning.v1.TuningTypePromptTuneH\x00\x12[\n\tscheduler\x18\xc8\x01 \x01(\x0b\x32G.yandex.cloud.ai.tuning.v1.TextClassificationMultilabelParams.Scheduler\x12[\n\toptimizer\x18\xc9\x01 \x01(\x0b\x32G.yandex.cloud.ai.tuning.v1.TextClassificationMultilabelParams.Optimizer\x1a\xed\x01\n\tScheduler\x12<\n\x06linear\x18\x01 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerLinearH\x00\x12@\n\x08\x63onstant\x18\x02 \x01(\x0b\x32,.yandex.cloud.ai.tuning.v1.SchedulerConstantH\x00\x12<\n\x06\x63osine\x18\x03 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerCosineH\x00\x12\x14\n\x0cwarmup_ratio\x18\x65 \x01(\x01\x42\x06\n\x04typeJ\x04\x08\x04\x10\x65\x1aO\n\tOptimizer\x12:\n\x05\x61\x64\x61mw\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.OptimizerAdamwH\x00\x42\x06\n\x04typeB\r\n\x0btuning_typeJ\x04\x08\x04\x10\x07J\x04\x08\x08\x10\x64J\x05\x08\x66\x10\xc8\x01\"\x8f\x06\n\"TextClassificationMulticlassParams\x12\x0c\n\x04seed\x18\x01 \x01(\x03\x12\n\n\x02lr\x18\x02 \x01(\x01\x12\x11\n\tn_samples\x18\x03 \x01(\x03\x12\x1c\n\x14\x61\x64\x64itional_arguments\x18\x07 \x01(\t\x12\x39\n\x04lora\x18\x64 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.TuningTypeLoraH\x00\x12\x46\n\x0bprompt_tune\x18\x65 \x01(\x0b\x32/.yandex.cloud.ai.tuning.v1.TuningTypePromptTuneH\x00\x12[\n\tscheduler\x18\xc8\x01 \x01(\x0b\x32G.yandex.cloud.ai.tuning.v1.TextClassificationMulticlassParams.Scheduler\x12[\n\toptimizer\x18\xc9\x01 \x01(\x0b\x32G.yandex.cloud.ai.tuning.v1.TextClassificationMulticlassParams.Optimizer\x1a\xed\x01\n\tScheduler\x12<\n\x06linear\x18\x01 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerLinearH\x00\x12@\n\x08\x63onstant\x18\x02 \x01(\x0b\x32,.yandex.cloud.ai.tuning.v1.SchedulerConstantH\x00\x12<\n\x06\x63osine\x18\x03 \x01(\x0b\x32*.yandex.cloud.ai.tuning.v1.SchedulerCosineH\x00\x12\x14\n\x0cwarmup_ratio\x18\x65 \x01(\x01\x42\x06\n\x04typeJ\x04\x08\x04\x10\x65\x1aO\n\tOptimizer\x12:\n\x05\x61\x64\x61mw\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.tuning.v1.OptimizerAdamwH\x00\x42\x06\n\x04typeB\r\n\x0btuning_typeJ\x04\x08\x04\x10\x07J\x04\x08\x08\x10\x64J\x05\x08\x66\x10\xc8\x01\"-\n\x14GetMetricsUrlRequest\x12\x15\n\x07task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\")\n\x15GetMetricsUrlResponse\x12\x10\n\x08load_url\x18\x01 \x01(\t\"*\n\x11GetOptionsRequest\x12\x15\n\x07task_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xdd\x02\n\x12GetOptionsResponse\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x16\n\x0e\x62\x61se_model_uri\x18\x02 \x01(\t\x12P\n\x0etrain_datasets\x18\x03 \x03(\x0b\x32\x38.yandex.cloud.ai.tuning.v1.TuningRequest.WeightedDataset\x12U\n\x13validation_datasets\x18\x04 \x03(\x0b\x32\x38.yandex.cloud.ai.tuning.v1.TuningRequest.WeightedDataset\x12^\n\x17text_to_text_completion\x18\x64 \x01(\x0b\x32;.yandex.cloud.ai.tuning.v1.TextToTextCompletionTuningParamsH\x00\x42\x0f\n\rtuning_paramsJ\x04\x08\x05\x10\x64\x32\xac\x05\n\rTuningService\x12y\n\x04Tune\x12(.yandex.cloud.ai.tuning.v1.TuningRequest\x1a!.yandex.cloud.operation.Operation\"$\xb2\xd2* \n\x0eTuningMetadata\x12\x0eTuningResponse\x12\x65\n\x04List\x12-.yandex.cloud.ai.tuning.v1.ListTuningsRequest\x1a..yandex.cloud.ai.tuning.v1.ListTuningsResponse\x12o\n\x08\x44\x65scribe\x12\x30.yandex.cloud.ai.tuning.v1.DescribeTuningRequest\x1a\x31.yandex.cloud.ai.tuning.v1.DescribeTuningResponse\x12i\n\x06\x43\x61ncel\x12..yandex.cloud.ai.tuning.v1.CancelTuningRequest\x1a/.yandex.cloud.ai.tuning.v1.CancelTuningResponse\x12r\n\rGetMetricsUrl\x12/.yandex.cloud.ai.tuning.v1.GetMetricsUrlRequest\x1a\x30.yandex.cloud.ai.tuning.v1.GetMetricsUrlResponse\x12i\n\nGetOptions\x12,.yandex.cloud.ai.tuning.v1.GetOptionsRequest\x1a-.yandex.cloud.ai.tuning.v1.GetOptionsResponseBc\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _LISTTUNINGSREQUEST.fields_by_name['folder_id']._options = None
  _LISTTUNINGSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _DESCRIBETUNINGREQUEST.fields_by_name['tuning_task_id']._options = None
  _DESCRIBETUNINGREQUEST.fields_by_name['tuning_task_id']._serialized_options = b'\350\3071\001'
  _CANCELTUNINGREQUEST.fields_by_name['tuning_task_id']._options = None
  _CANCELTUNINGREQUEST.fields_by_name['tuning_task_id']._serialized_options = b'\350\3071\001'
  _TUNINGREQUEST_LABELSENTRY._options = None
  _TUNINGREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _TUNINGREQUEST_WEIGHTEDDATASET.fields_by_name['dataset_id']._options = None
  _TUNINGREQUEST_WEIGHTEDDATASET.fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _TUNINGREQUEST.fields_by_name['base_model_uri']._options = None
  _TUNINGREQUEST.fields_by_name['base_model_uri']._serialized_options = b'\350\3071\001'
  _TUNINGREQUEST.fields_by_name['train_datasets']._options = None
  _TUNINGREQUEST.fields_by_name['train_datasets']._serialized_options = b'\202\3101\002>0'
  _GETMETRICSURLREQUEST.fields_by_name['task_id']._options = None
  _GETMETRICSURLREQUEST.fields_by_name['task_id']._serialized_options = b'\350\3071\001'
  _GETOPTIONSREQUEST.fields_by_name['task_id']._options = None
  _GETOPTIONSREQUEST.fields_by_name['task_id']._serialized_options = b'\350\3071\001'
  _TUNINGSERVICE.methods_by_name['Tune']._options = None
  _TUNINGSERVICE.methods_by_name['Tune']._serialized_options = b'\262\322* \n\016TuningMetadata\022\016TuningResponse'
  _globals['_LISTTUNINGSREQUEST']._serialized_start=375
  _globals['_LISTTUNINGSREQUEST']._serialized_end=459
  _globals['_LISTTUNINGSRESPONSE']._serialized_start=461
  _globals['_LISTTUNINGSRESPONSE']._serialized_end=568
  _globals['_DESCRIBETUNINGREQUEST']._serialized_start=570
  _globals['_DESCRIBETUNINGREQUEST']._serialized_end=623
  _globals['_DESCRIBETUNINGRESPONSE']._serialized_start=625
  _globals['_DESCRIBETUNINGRESPONSE']._serialized_end=709
  _globals['_CANCELTUNINGREQUEST']._serialized_start=711
  _globals['_CANCELTUNINGREQUEST']._serialized_end=762
  _globals['_CANCELTUNINGRESPONSE']._serialized_start=764
  _globals['_CANCELTUNINGRESPONSE']._serialized_end=810
  _globals['_TUNINGRESPONSE']._serialized_start=813
  _globals['_TUNINGRESPONSE']._serialized_end=953
  _globals['_TUNINGMETADATA']._serialized_start=955
  _globals['_TUNINGMETADATA']._serialized_end=1057
  _globals['_TUNINGREQUEST']._serialized_start=1060
  _globals['_TUNINGREQUEST']._serialized_end=1834
  _globals['_TUNINGREQUEST_LABELSENTRY']._serialized_start=1698
  _globals['_TUNINGREQUEST_LABELSENTRY']._serialized_end=1743
  _globals['_TUNINGREQUEST_WEIGHTEDDATASET']._serialized_start=1745
  _globals['_TUNINGREQUEST_WEIGHTEDDATASET']._serialized_end=1804
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS']._serialized_start=1837
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS']._serialized_end=2614
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS_SCHEDULER']._serialized_start=2262
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS_SCHEDULER']._serialized_end=2499
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS_OPTIMIZER']._serialized_start=2501
  _globals['_TEXTTOTEXTCOMPLETIONTUNINGPARAMS_OPTIMIZER']._serialized_end=2580
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS']._serialized_start=2617
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS']._serialized_end=3400
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS_SCHEDULER']._serialized_start=2262
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS_SCHEDULER']._serialized_end=2499
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS_OPTIMIZER']._serialized_start=2501
  _globals['_TEXTCLASSIFICATIONMULTILABELPARAMS_OPTIMIZER']._serialized_end=2580
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS']._serialized_start=3403
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS']._serialized_end=4186
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS_SCHEDULER']._serialized_start=2262
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS_SCHEDULER']._serialized_end=2499
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS_OPTIMIZER']._serialized_start=2501
  _globals['_TEXTCLASSIFICATIONMULTICLASSPARAMS_OPTIMIZER']._serialized_end=2580
  _globals['_GETMETRICSURLREQUEST']._serialized_start=4188
  _globals['_GETMETRICSURLREQUEST']._serialized_end=4233
  _globals['_GETMETRICSURLRESPONSE']._serialized_start=4235
  _globals['_GETMETRICSURLRESPONSE']._serialized_end=4276
  _globals['_GETOPTIONSREQUEST']._serialized_start=4278
  _globals['_GETOPTIONSREQUEST']._serialized_end=4320
  _globals['_GETOPTIONSRESPONSE']._serialized_start=4323
  _globals['_GETOPTIONSRESPONSE']._serialized_end=4672
  _globals['_TUNINGSERVICE']._serialized_start=4675
  _globals['_TUNINGSERVICE']._serialized_end=5359
# @@protoc_insertion_point(module_scope)
