# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cloudrouter/v1/routing_instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.cloudrouter.v1 import routing_instance_pb2 as yandex_dot_cloud_dot_cloudrouter_dot_v1_dot_routing__instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/cloudrouter/v1/routing_instance_service.proto\x12\x1byandex.cloud.cloudrouter.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x32yandex/cloud/cloudrouter/v1/routing_instance.proto\"F\n\x19GetRoutingInstanceRequest\x12)\n\x13routing_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"d\n1GetRoutingInstanceByCicPrivateConnectionIdRequest\x12/\n\x19\x63ic_private_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"O\n\'GetRoutingInstanceByVpcNetworkIdRequest\x12$\n\x0evpc_network_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x98\x01\n\x1bListRoutingInstancesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x80\x01\n\x1cListRoutingInstancesResponse\x12G\n\x11routing_instances\x18\x01 \x03(\x0b\x32,.yandex.cloud.cloudrouter.v1.RoutingInstance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xfd\x04\n\x16RoutingInstanceService\x12\x9e\x01\n\x03Get\x12\x36.yandex.cloud.cloudrouter.v1.GetRoutingInstanceRequest\x1a,.yandex.cloud.cloudrouter.v1.RoutingInstance\"1\x82\xd3\xe4\x93\x02+\x12)/vpc/v1/cloudrouter/{routing_instance_id}\x12\x87\x01\n\x11GetByVpcNetworkId\x12\x44.yandex.cloud.cloudrouter.v1.GetRoutingInstanceByVpcNetworkIdRequest\x1a,.yandex.cloud.cloudrouter.v1.RoutingInstance\x12\x9b\x01\n\x1bGetByCicPrivateConnectionId\x12N.yandex.cloud.cloudrouter.v1.GetRoutingInstanceByCicPrivateConnectionIdRequest\x1a,.yandex.cloud.cloudrouter.v1.RoutingInstance\x12\x99\x01\n\x04List\x12\x38.yandex.cloud.cloudrouter.v1.ListRoutingInstancesRequest\x1a\x39.yandex.cloud.cloudrouter.v1.ListRoutingInstancesResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/vpc/v1/cloudroutersBn\n\x1fyandex.cloud.api.cloudrouter.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudrouter/v1;cloudrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudrouter.v1.routing_instance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.cloudrouter.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudrouter/v1;cloudrouter'
  _GETROUTINGINSTANCEREQUEST.fields_by_name['routing_instance_id']._options = None
  _GETROUTINGINSTANCEREQUEST.fields_by_name['routing_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST.fields_by_name['cic_private_connection_id']._options = None
  _GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST.fields_by_name['cic_private_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST.fields_by_name['vpc_network_id']._options = None
  _GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST.fields_by_name['vpc_network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['folder_id']._options = None
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['page_size']._options = None
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['page_token']._options = None
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['filter']._options = None
  _LISTROUTINGINSTANCESREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _ROUTINGINSTANCESERVICE.methods_by_name['Get']._options = None
  _ROUTINGINSTANCESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/vpc/v1/cloudrouter/{routing_instance_id}'
  _ROUTINGINSTANCESERVICE.methods_by_name['List']._options = None
  _ROUTINGINSTANCESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/vpc/v1/cloudrouters'
  _globals['_GETROUTINGINSTANCEREQUEST']._serialized_start=204
  _globals['_GETROUTINGINSTANCEREQUEST']._serialized_end=274
  _globals['_GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST']._serialized_start=276
  _globals['_GETROUTINGINSTANCEBYCICPRIVATECONNECTIONIDREQUEST']._serialized_end=376
  _globals['_GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST']._serialized_start=378
  _globals['_GETROUTINGINSTANCEBYVPCNETWORKIDREQUEST']._serialized_end=457
  _globals['_LISTROUTINGINSTANCESREQUEST']._serialized_start=460
  _globals['_LISTROUTINGINSTANCESREQUEST']._serialized_end=612
  _globals['_LISTROUTINGINSTANCESRESPONSE']._serialized_start=615
  _globals['_LISTROUTINGINSTANCESRESPONSE']._serialized_end=743
  _globals['_ROUTINGINSTANCESERVICE']._serialized_start=746
  _globals['_ROUTINGINSTANCESERVICE']._serialized_end=1383
# @@protoc_insertion_point(module_scope)
