# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/project_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.speechsense.v1 import project_pb2 as yandex_dot_cloud_dot_speechsense_dot_v1_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/speechsense/v1/project_service.proto\x12\x1byandex.cloud.speechsense.v1\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a)yandex/cloud/speechsense/v1/project.proto\"\x8b\x01\n\x14\x43reateProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x39\n\x07\x66ilters\x18\x04 \x03(\x0b\x32(.yandex.cloud.speechsense.v1.FieldFilter\"#\n\x15\x43reateProjectMetadata\x12\n\n\x02id\x18\x01 \x01(\t2\x97\x01\n\x0eProjectService\x12\x84\x01\n\x06\x43reate\x12\x31.yandex.cloud.speechsense.v1.CreateProjectRequest\x1a!.yandex.cloud.operation.Operation\"$\xb2\xd2* \n\x15\x43reateProjectMetadata\x12\x07ProjectB\x83\x01\n\x1fyandex.cloud.api.speechsense.v1B\x13ProjectServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.project_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\023ProjectServiceProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _PROJECTSERVICE.methods_by_name['Create']._options = None
  _PROJECTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateProjectMetadata\022\007Project'
  _globals['_CREATEPROJECTREQUEST']._serialized_start=200
  _globals['_CREATEPROJECTREQUEST']._serialized_end=339
  _globals['_CREATEPROJECTMETADATA']._serialized_start=341
  _globals['_CREATEPROJECTMETADATA']._serialized_end=376
  _globals['_PROJECTSERVICE']._serialized_start=379
  _globals['_PROJECTSERVICE']._serialized_end=530
# @@protoc_insertion_point(module_scope)
