"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.common.tag_pb2
import yandex.cloud.loadtesting.api.v1.test.artifact_settings_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Details(google.protobuf.message.Message):
    """Test meta information."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    LOGGING_LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    ARTIFACT_SETTINGS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the test."""
    description: builtins.str
    """Description of the test."""
    logging_log_group_id: builtins.str
    """ID of the logging group to which test artifacts are uploaded."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.common.tag_pb2.Tag]:
        """Tags assigned to the test."""

    @property
    def artifact_settings(self) -> yandex.cloud.loadtesting.api.v1.test.artifact_settings_pb2.ArtifactSettings:
        """Settings which define where to upload test artifacts and which files should be included."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.common.tag_pb2.Tag] | None = ...,
        logging_log_group_id: builtins.str = ...,
        artifact_settings: yandex.cloud.loadtesting.api.v1.test.artifact_settings_pb2.ArtifactSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["artifact_settings", b"artifact_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["artifact_settings", b"artifact_settings", "description", b"description", "logging_log_group_id", b"logging_log_group_id", "name", b"name", "tags", b"tags"]) -> None: ...

global___Details = Details
