# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.smartwebsecurity.v1.waf import rule_set_descriptor_pb2 as yandex_dot_cloud_dot_smartwebsecurity_dot_v1_dot_waf_dot_rule__set__descriptor__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFyandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor_service.proto\x12$yandex.cloud.smartwebsecurity.v1.waf\x1a>yandex/cloud/smartwebsecurity/v1/waf/rule_set_descriptor.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"H\n\x1bGetRuleSetDescriptorRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xe3\x01\n\x18RuleSetDescriptorService\x12\xc6\x01\n\x03Get\x12\x41.yandex.cloud.smartwebsecurity.v1.waf.GetRuleSetDescriptorRequest\x1a\x37.yandex.cloud.smartwebsecurity.v1.waf.RuleSetDescriptor\"C\x82\xd3\xe4\x93\x02=\x12;/smartwebsecurity/v1/wafRuleSetDescriptors/{name}/{version}B\x85\x01\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.waf.rule_set_descriptor_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurity'
  _GETRULESETDESCRIPTORREQUEST.fields_by_name['name']._options = None
  _GETRULESETDESCRIPTORREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _GETRULESETDESCRIPTORREQUEST.fields_by_name['version']._options = None
  _GETRULESETDESCRIPTORREQUEST.fields_by_name['version']._serialized_options = b'\350\3071\001'
  _RULESETDESCRIPTORSERVICE.methods_by_name['Get']._options = None
  _RULESETDESCRIPTORSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002=\022;/smartwebsecurity/v1/wafRuleSetDescriptors/{name}/{version}'
  _globals['_GETRULESETDESCRIPTORREQUEST']._serialized_start=237
  _globals['_GETRULESETDESCRIPTORREQUEST']._serialized_end=309
  _globals['_RULESETDESCRIPTORSERVICE']._serialized_start=312
  _globals['_RULESETDESCRIPTORSERVICE']._serialized_end=539
# @@protoc_insertion_point(module_scope)
