# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/node_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.k8s.v1 import node_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__pb2
from yandex.cloud.k8s.v1 import node_group_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_node__group__pb2
from yandex.cloud.k8s.v1 import version_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/k8s/v1/node_group_service.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x1eyandex/cloud/k8s/v1/node.proto\x1a$yandex/cloud/k8s/v1/node_group.proto\x1a!yandex/cloud/k8s/v1/version.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"2\n\x13GetNodeGroupRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8a\x01\n\x15ListNodeGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"f\n\x16ListNodeGroupsResponse\x12\x33\n\x0bnode_groups\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.k8s.v1.NodeGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"v\n\x19ListNodeGroupNodesRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"_\n\x1aListNodeGroupNodesResponse\x12(\n\x05nodes\x18\x01 \x03(\x0b\x32\x19.yandex.cloud.k8s.v1.Node\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x16\x44\x65leteNodeGroupRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15\n\rnode_group_id\x18\x01 \x01(\t\"\xa2\x08\n\x16UpdateNodeGroupRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x37.yandex.cloud.k8s.v1.UpdateNodeGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x38\n\rnode_template\x18\x08 \x01(\x0b\x32!.yandex.cloud.k8s.v1.NodeTemplate\x12\x36\n\x0cscale_policy\x18\x06 \x01(\x0b\x32 .yandex.cloud.k8s.v1.ScalePolicy\x12I\n\x11\x61llocation_policy\x18\t \x01(\x0b\x32..yandex.cloud.k8s.v1.NodeGroupAllocationPolicy\x12\x38\n\rdeploy_policy\x18\x0f \x01(\x0b\x32!.yandex.cloud.k8s.v1.DeployPolicy\x12\x37\n\x07version\x18\n \x01(\x0b\x32&.yandex.cloud.k8s.v1.UpdateVersionSpec\x12K\n\x12maintenance_policy\x18\x0b \x01(\x0b\x32/.yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy\x12o\n\x16\x61llowed_unsafe_sysctls\x18\x0c \x03(\tBO\xf2\xc7\x31\x42([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\x8a\xc8\x31\x05<=253\x12/\n\x0bnode_taints\x18\r \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12P\n\x0bnode_labels\x18\x0e \x03(\x0b\x32;.yandex.cloud.k8s.v1.UpdateNodeGroupRequest.NodeLabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"6\n\x17UpdateNodeGroupMetadata\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xcc\x07\n\x16\x43reateNodeGroupRequest\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x37.yandex.cloud.k8s.v1.CreateNodeGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12>\n\rnode_template\x18\x05 \x01(\x0b\x32!.yandex.cloud.k8s.v1.NodeTemplateB\x04\xe8\xc7\x31\x01\x12<\n\x0cscale_policy\x18\x06 \x01(\x0b\x32 .yandex.cloud.k8s.v1.ScalePolicyB\x04\xe8\xc7\x31\x01\x12I\n\x11\x61llocation_policy\x18\x07 \x01(\x0b\x32..yandex.cloud.k8s.v1.NodeGroupAllocationPolicy\x12\x38\n\rdeploy_policy\x18\r \x01(\x0b\x32!.yandex.cloud.k8s.v1.DeployPolicy\x12\x0f\n\x07version\x18\x08 \x01(\t\x12K\n\x12maintenance_policy\x18\t \x01(\x0b\x32/.yandex.cloud.k8s.v1.NodeGroupMaintenancePolicy\x12o\n\x16\x61llowed_unsafe_sysctls\x18\n \x03(\tBO\xf2\xc7\x31\x42([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\x8a\xc8\x31\x05<=253\x12/\n\x0bnode_taints\x18\x0b \x03(\x0b\x32\x1a.yandex.cloud.k8s.v1.Taint\x12P\n\x0bnode_labels\x18\x0c \x03(\x0b\x32;.yandex.cloud.k8s.v1.CreateNodeGroupRequest.NodeLabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"0\n\x17\x43reateNodeGroupMetadata\x12\x15\n\rnode_group_id\x18\x01 \x01(\t\"5\n\x1c\x41utoUpgradeNodeGroupMetadata\x12\x15\n\rnode_group_id\x18\x01 \x01(\t\"\x97\x01\n\x1eListNodeGroupOperationsRequest\x12\x1b\n\rnode_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"q\n\x1fListNodeGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc1\t\n\x10NodeGroupService\x12\x8a\x01\n\x03Get\x12(.yandex.cloud.k8s.v1.GetNodeGroupRequest\x1a\x1e.yandex.cloud.k8s.v1.NodeGroup\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/managed-kubernetes/v1/nodeGroups/{node_group_id}\x12\x8a\x01\n\x04List\x12*.yandex.cloud.k8s.v1.ListNodeGroupsRequest\x1a+.yandex.cloud.k8s.v1.ListNodeGroupsResponse\")\x82\xd3\xe4\x93\x02#\x12!/managed-kubernetes/v1/nodeGroups\x12\xae\x01\n\x06\x43reate\x12+.yandex.cloud.k8s.v1.CreateNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*$\n\x17\x43reateNodeGroupMetadata\x12\tNodeGroup\x82\xd3\xe4\x93\x02&\"!/managed-kubernetes/v1/nodeGroups:\x01*\x12\xbe\x01\n\x06Update\x12+.yandex.cloud.k8s.v1.UpdateNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*$\n\x17UpdateNodeGroupMetadata\x12\tNodeGroup\x82\xd3\xe4\x93\x02\x36\x32\x31/managed-kubernetes/v1/nodeGroups/{node_group_id}:\x01*\x12\xc7\x01\n\x06\x44\x65lete\x12+.yandex.cloud.k8s.v1.DeleteNodeGroupRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*0\n\x17\x44\x65leteNodeGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x33*1/managed-kubernetes/v1/nodeGroups/{node_group_id}\x12\xc1\x01\n\x0eListOperations\x12\x33.yandex.cloud.k8s.v1.ListNodeGroupOperationsRequest\x1a\x34.yandex.cloud.k8s.v1.ListNodeGroupOperationsResponse\"D\x82\xd3\xe4\x93\x02>\x12</managed-kubernetes/v1/nodeGroups/{node_group_id}/operations\x12\x92\x01\n\tListNodes\x12..yandex.cloud.k8s.v1.ListNodeGroupNodesRequest\x1a/.yandex.cloud.k8s.v1.ListNodeGroupNodesResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/managed-kubernetes/v1/nodesBV\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.v1.node_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s'
  _GETNODEGROUPREQUEST.fields_by_name['node_group_id']._options = None
  _GETNODEGROUPREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _LISTNODEGROUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _LISTNODEGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTNODEGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTNODEGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTNODEGROUPNODESREQUEST.fields_by_name['node_group_id']._options = None
  _LISTNODEGROUPNODESREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _LISTNODEGROUPNODESREQUEST.fields_by_name['page_size']._options = None
  _LISTNODEGROUPNODESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTNODEGROUPNODESREQUEST.fields_by_name['page_token']._options = None
  _LISTNODEGROUPNODESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _DELETENODEGROUPREQUEST.fields_by_name['node_group_id']._options = None
  _DELETENODEGROUPREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _UPDATENODEGROUPREQUEST_LABELSENTRY._options = None
  _UPDATENODEGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATENODEGROUPREQUEST_NODELABELSENTRY._options = None
  _UPDATENODEGROUPREQUEST_NODELABELSENTRY._serialized_options = b'8\001'
  _UPDATENODEGROUPREQUEST.fields_by_name['node_group_id']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _UPDATENODEGROUPREQUEST.fields_by_name['name']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATENODEGROUPREQUEST.fields_by_name['description']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATENODEGROUPREQUEST.fields_by_name['labels']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._serialized_options = b'\362\3071B([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\212\3101\005<=253'
  _UPDATENODEGROUPMETADATA.fields_by_name['node_group_id']._options = None
  _UPDATENODEGROUPMETADATA.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _CREATENODEGROUPREQUEST_LABELSENTRY._options = None
  _CREATENODEGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATENODEGROUPREQUEST_NODELABELSENTRY._options = None
  _CREATENODEGROUPREQUEST_NODELABELSENTRY._serialized_options = b'8\001'
  _CREATENODEGROUPREQUEST.fields_by_name['cluster_id']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _CREATENODEGROUPREQUEST.fields_by_name['name']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATENODEGROUPREQUEST.fields_by_name['description']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATENODEGROUPREQUEST.fields_by_name['labels']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATENODEGROUPREQUEST.fields_by_name['node_template']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['node_template']._serialized_options = b'\350\3071\001'
  _CREATENODEGROUPREQUEST.fields_by_name['scale_policy']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['scale_policy']._serialized_options = b'\350\3071\001'
  _CREATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['allowed_unsafe_sysctls']._serialized_options = b'\362\3071B([a-z0-9]([-_a-z0-9]*[a-z0-9])?\\.)*([a-z0-9][-_a-z0-9]*)?[a-z0-9*]\212\3101\005<=253'
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['node_group_id']._options = None
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['node_group_id']._serialized_options = b'\350\3071\001'
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTNODEGROUPOPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _NODEGROUPSERVICE.methods_by_name['Get']._options = None
  _NODEGROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0023\0221/managed-kubernetes/v1/nodeGroups/{node_group_id}'
  _NODEGROUPSERVICE.methods_by_name['List']._options = None
  _NODEGROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/managed-kubernetes/v1/nodeGroups'
  _NODEGROUPSERVICE.methods_by_name['Create']._options = None
  _NODEGROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateNodeGroupMetadata\022\tNodeGroup\202\323\344\223\002&\"!/managed-kubernetes/v1/nodeGroups:\001*'
  _NODEGROUPSERVICE.methods_by_name['Update']._options = None
  _NODEGROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateNodeGroupMetadata\022\tNodeGroup\202\323\344\223\002621/managed-kubernetes/v1/nodeGroups/{node_group_id}:\001*'
  _NODEGROUPSERVICE.methods_by_name['Delete']._options = None
  _NODEGROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteNodeGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0023*1/managed-kubernetes/v1/nodeGroups/{node_group_id}'
  _NODEGROUPSERVICE.methods_by_name['ListOperations']._options = None
  _NODEGROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002>\022</managed-kubernetes/v1/nodeGroups/{node_group_id}/operations'
  _NODEGROUPSERVICE.methods_by_name['ListNodes']._options = None
  _NODEGROUPSERVICE.methods_by_name['ListNodes']._serialized_options = b'\202\323\344\223\002\036\022\034/managed-kubernetes/v1/nodes'
  _globals['_GETNODEGROUPREQUEST']._serialized_start=343
  _globals['_GETNODEGROUPREQUEST']._serialized_end=393
  _globals['_LISTNODEGROUPSREQUEST']._serialized_start=396
  _globals['_LISTNODEGROUPSREQUEST']._serialized_end=534
  _globals['_LISTNODEGROUPSRESPONSE']._serialized_start=536
  _globals['_LISTNODEGROUPSRESPONSE']._serialized_end=638
  _globals['_LISTNODEGROUPNODESREQUEST']._serialized_start=640
  _globals['_LISTNODEGROUPNODESREQUEST']._serialized_end=758
  _globals['_LISTNODEGROUPNODESRESPONSE']._serialized_start=760
  _globals['_LISTNODEGROUPNODESRESPONSE']._serialized_end=855
  _globals['_DELETENODEGROUPREQUEST']._serialized_start=857
  _globals['_DELETENODEGROUPREQUEST']._serialized_end=910
  _globals['_DELETENODEGROUPMETADATA']._serialized_start=912
  _globals['_DELETENODEGROUPMETADATA']._serialized_end=960
  _globals['_UPDATENODEGROUPREQUEST']._serialized_start=963
  _globals['_UPDATENODEGROUPREQUEST']._serialized_end=2021
  _globals['_UPDATENODEGROUPREQUEST_LABELSENTRY']._serialized_start=1919
  _globals['_UPDATENODEGROUPREQUEST_LABELSENTRY']._serialized_end=1964
  _globals['_UPDATENODEGROUPREQUEST_NODELABELSENTRY']._serialized_start=1966
  _globals['_UPDATENODEGROUPREQUEST_NODELABELSENTRY']._serialized_end=2015
  _globals['_UPDATENODEGROUPMETADATA']._serialized_start=2023
  _globals['_UPDATENODEGROUPMETADATA']._serialized_end=2077
  _globals['_CREATENODEGROUPREQUEST']._serialized_start=2080
  _globals['_CREATENODEGROUPREQUEST']._serialized_end=3052
  _globals['_CREATENODEGROUPREQUEST_LABELSENTRY']._serialized_start=1919
  _globals['_CREATENODEGROUPREQUEST_LABELSENTRY']._serialized_end=1964
  _globals['_CREATENODEGROUPREQUEST_NODELABELSENTRY']._serialized_start=1966
  _globals['_CREATENODEGROUPREQUEST_NODELABELSENTRY']._serialized_end=2015
  _globals['_CREATENODEGROUPMETADATA']._serialized_start=3054
  _globals['_CREATENODEGROUPMETADATA']._serialized_end=3102
  _globals['_AUTOUPGRADENODEGROUPMETADATA']._serialized_start=3104
  _globals['_AUTOUPGRADENODEGROUPMETADATA']._serialized_end=3157
  _globals['_LISTNODEGROUPOPERATIONSREQUEST']._serialized_start=3160
  _globals['_LISTNODEGROUPOPERATIONSREQUEST']._serialized_end=3311
  _globals['_LISTNODEGROUPOPERATIONSRESPONSE']._serialized_start=3313
  _globals['_LISTNODEGROUPOPERATIONSRESPONSE']._serialized_end=3426
  _globals['_NODEGROUPSERVICE']._serialized_start=3429
  _globals['_NODEGROUPSERVICE']._serialized_end=4646
# @@protoc_insertion_point(module_scope)
