# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/database.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ydb.v1 import backup_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/ydb/v1/database.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/ydb/v1/backup.proto\"\xb3\t\n\x08\x44\x61tabase\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x34\n\x06status\x18\x06 \x01(\x0e\x32$.yandex.cloud.ydb.v1.Database.Status\x12\x10\n\x08\x65ndpoint\x18\x08 \x01(\t\x12\x1a\n\x12resource_preset_id\x18\t \x01(\t\x12:\n\x0estorage_config\x18\n \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x0b \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\x0c \x01(\t\x12\x12\n\nsubnet_ids\x18\r \x03(\t\x12<\n\x0ezonal_database\x18\x0e \x01(\x0b\x32\".yandex.cloud.ydb.v1.ZonalDatabaseH\x00\x12\x42\n\x11regional_database\x18\x0f \x01(\x0b\x32%.yandex.cloud.ydb.v1.RegionalDatabaseH\x00\x12\x44\n\x12\x64\x65\x64icated_database\x18\x12 \x01(\x0b\x32&.yandex.cloud.ydb.v1.DedicatedDatabaseH\x00\x12\x46\n\x13serverless_database\x18\x13 \x01(\x0b\x32\'.yandex.cloud.ydb.v1.ServerlessDatabaseH\x00\x12\x19\n\x11\x61ssign_public_ips\x18\x10 \x01(\x08\x12\x13\n\x0blocation_id\x18\x11 \x01(\t\x12\x39\n\x06labels\x18\x14 \x03(\x0b\x32).yandex.cloud.ydb.v1.Database.LabelsEntry\x12\x38\n\rbackup_config\x18\x15 \x01(\x0b\x32!.yandex.cloud.ydb.v1.BackupConfig\x12\x1d\n\x15\x64ocument_api_endpoint\x18\x16 \x01(\t\x12\x1c\n\x14kinesis_api_endpoint\x18\x17 \x01(\t\x12\x1a\n\x12kafka_api_endpoint\x18\x1a \x01(\t\x12@\n\x11monitoring_config\x18\x18 \x01(\x0b\x32%.yandex.cloud.ydb.v1.MonitoringConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x19 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08UPDATING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\x0c\n\x08STARTING\x10\x07\x12\x0b\n\x07STOPPED\x10\x08\x42\x0f\n\rdatabase_typeJ\x04\x08\x07\x10\x08\"\x82\x06\n\x0e\x41lertParameter\x12Z\n\x16\x64ouble_parameter_value\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.ydb.v1.AlertParameter.DoubleParameterValueH\x00\x12\\\n\x17integer_parameter_value\x18\x02 \x01(\x0b\x32\x39.yandex.cloud.ydb.v1.AlertParameter.IntegerParameterValueH\x00\x12V\n\x14text_parameter_value\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.ydb.v1.AlertParameter.TextParameterValueH\x00\x12_\n\x19text_list_parameter_value\x18\x04 \x01(\x0b\x32:.yandex.cloud.ydb.v1.AlertParameter.TextListParameterValueH\x00\x12\x61\n\x1alabel_list_parameter_value\x18\x05 \x01(\x0b\x32;.yandex.cloud.ydb.v1.AlertParameter.LabelListParameterValueH\x00\x1a\x33\n\x14\x44oubleParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x1a\x34\n\x15IntegerParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03\x1a\x31\n\x12TextParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x36\n\x16TextListParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\x1a\x37\n\x17LabelListParameterValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\tB\x0b\n\tparameter\"\xa2\x01\n\x13NotificationChannel\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12I\n\x15notify_about_statuses\x18\x02 \x03(\x0e\x32*.yandex.cloud.ydb.v1.AlertEvaluationStatus\x12\x1f\n\x17repeate_notify_delay_ms\x18\x03 \x01(\x03\"\x9e\x02\n\x05\x41lert\x12\x10\n\x08\x61lert_id\x18\x01 \x01(\t\x12\x19\n\x11\x61lert_template_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12G\n\x15notification_channels\x18\x05 \x03(\x0b\x32(.yandex.cloud.ydb.v1.NotificationChannel\x12=\n\x10\x61lert_parameters\x18\x06 \x03(\x0b\x32#.yandex.cloud.ydb.v1.AlertParameter\x12=\n\x10\x61lert_thresholds\x18\x07 \x03(\x0b\x32#.yandex.cloud.ydb.v1.AlertParameter\">\n\x10MonitoringConfig\x12*\n\x06\x61lerts\x18\x01 \x03(\x0b\x32\x1a.yandex.cloud.ydb.v1.Alert\"\xe6\x01\n\x11\x44\x65\x64icatedDatabase\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12:\n\x0estorage_config\x18\x02 \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x03 \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\x04 \x01(\t\x12\x12\n\nsubnet_ids\x18\x05 \x03(\t\x12\x19\n\x11\x61ssign_public_ips\x18\x06 \x01(\x08\"\xad\x01\n\x12ServerlessDatabase\x12\x1c\n\x14throttling_rcu_limit\x18\x01 \x01(\x03\x12\x1a\n\x12storage_size_limit\x18\x02 \x01(\x03\x12#\n\x1b\x65nable_throttling_rcu_limit\x18\x03 \x01(\x08\x12\x1d\n\x15provisioned_rcu_limit\x18\x04 \x01(\x03\x12\x19\n\x11topic_write_quota\x18\x05 \x01(\x03\"&\n\rZonalDatabase\x12\x15\n\x07zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"+\n\x10RegionalDatabase\x12\x17\n\tregion_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8a\x01\n\x0bScalePolicy\x12\x42\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32+.yandex.cloud.ydb.v1.ScalePolicy.FixedScaleH\x00\x1a#\n\nFixedScale\x12\x15\n\x04size\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1B\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\"q\n\rStorageConfig\x12\x44\n\x0fstorage_options\x18\x01 \x03(\x0b\x32\".yandex.cloud.ydb.v1.StorageOptionB\x07\x82\xc8\x31\x03>=1\x12\x1a\n\x12storage_size_limit\x18\x02 \x01(\x03\"=\n\rStorageOption\x12\x17\n\x0fstorage_type_id\x18\x01 \x01(\t\x12\x13\n\x0bgroup_count\x18\x02 \x01(\x03*\xed\x01\n\x15\x41lertEvaluationStatus\x12\'\n#ALERT_EVALUATION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x41LERT_EVALUATION_STATUS_OK\x10\x01\x12#\n\x1f\x41LERT_EVALUATION_STATUS_NO_DATA\x10\x02\x12!\n\x1d\x41LERT_EVALUATION_STATUS_ERROR\x10\x03\x12!\n\x1d\x41LERT_EVALUATION_STATUS_ALARM\x10\x04\x12 \n\x1c\x41LERT_EVALUATION_STATUS_WARN\x10\x05\x42V\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ydb.v1.database_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb'
  _DATABASE_LABELSENTRY._options = None
  _DATABASE_LABELSENTRY._serialized_options = b'8\001'
  _ZONALDATABASE.fields_by_name['zone_id']._options = None
  _ZONALDATABASE.fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _REGIONALDATABASE.fields_by_name['region_id']._options = None
  _REGIONALDATABASE.fields_by_name['region_id']._serialized_options = b'\350\3071\001'
  _SCALEPOLICY_FIXEDSCALE.fields_by_name['size']._options = None
  _SCALEPOLICY_FIXEDSCALE.fields_by_name['size']._serialized_options = b'\372\3071\003>=1'
  _SCALEPOLICY.oneofs_by_name['scale_type']._options = None
  _SCALEPOLICY.oneofs_by_name['scale_type']._serialized_options = b'\300\3011\001'
  _STORAGECONFIG.fields_by_name['storage_options']._options = None
  _STORAGECONFIG.fields_by_name['storage_options']._serialized_options = b'\202\3101\003>=1'
  _globals['_ALERTEVALUATIONSTATUS']._serialized_start=3468
  _globals['_ALERTEVALUATIONSTATUS']._serialized_end=3705
  _globals['_DATABASE']._serialized_start=158
  _globals['_DATABASE']._serialized_end=1361
  _globals['_DATABASE_LABELSENTRY']._serialized_start=1161
  _globals['_DATABASE_LABELSENTRY']._serialized_end=1206
  _globals['_DATABASE_STATUS']._serialized_start=1209
  _globals['_DATABASE_STATUS']._serialized_end=1338
  _globals['_ALERTPARAMETER']._serialized_start=1364
  _globals['_ALERTPARAMETER']._serialized_end=2134
  _globals['_ALERTPARAMETER_DOUBLEPARAMETERVALUE']._serialized_start=1852
  _globals['_ALERTPARAMETER_DOUBLEPARAMETERVALUE']._serialized_end=1903
  _globals['_ALERTPARAMETER_INTEGERPARAMETERVALUE']._serialized_start=1905
  _globals['_ALERTPARAMETER_INTEGERPARAMETERVALUE']._serialized_end=1957
  _globals['_ALERTPARAMETER_TEXTPARAMETERVALUE']._serialized_start=1959
  _globals['_ALERTPARAMETER_TEXTPARAMETERVALUE']._serialized_end=2008
  _globals['_ALERTPARAMETER_TEXTLISTPARAMETERVALUE']._serialized_start=2010
  _globals['_ALERTPARAMETER_TEXTLISTPARAMETERVALUE']._serialized_end=2064
  _globals['_ALERTPARAMETER_LABELLISTPARAMETERVALUE']._serialized_start=2066
  _globals['_ALERTPARAMETER_LABELLISTPARAMETERVALUE']._serialized_end=2121
  _globals['_NOTIFICATIONCHANNEL']._serialized_start=2137
  _globals['_NOTIFICATIONCHANNEL']._serialized_end=2299
  _globals['_ALERT']._serialized_start=2302
  _globals['_ALERT']._serialized_end=2588
  _globals['_MONITORINGCONFIG']._serialized_start=2590
  _globals['_MONITORINGCONFIG']._serialized_end=2652
  _globals['_DEDICATEDDATABASE']._serialized_start=2655
  _globals['_DEDICATEDDATABASE']._serialized_end=2885
  _globals['_SERVERLESSDATABASE']._serialized_start=2888
  _globals['_SERVERLESSDATABASE']._serialized_end=3061
  _globals['_ZONALDATABASE']._serialized_start=3063
  _globals['_ZONALDATABASE']._serialized_end=3101
  _globals['_REGIONALDATABASE']._serialized_start=3103
  _globals['_REGIONALDATABASE']._serialized_end=3146
  _globals['_SCALEPOLICY']._serialized_start=3149
  _globals['_SCALEPOLICY']._serialized_end=3287
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_start=3232
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_end=3267
  _globals['_STORAGECONFIG']._serialized_start=3289
  _globals['_STORAGECONFIG']._serialized_end=3402
  _globals['_STORAGEOPTION']._serialized_start=3404
  _globals['_STORAGEOPTION']._serialized_end=3465
# @@protoc_insertion_point(module_scope)
