# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/log_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.logging.v1 import log_group_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2
from yandex.cloud.logging.v1 import log_resource_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/logging/v1/log_group_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\'yandex/cloud/logging/v1/log_group.proto\x1a*yandex/cloud/logging/v1/log_resource.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x12GetLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"=\n\x17GetLogGroupStatsRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\x85\x01\n\x14ListLogGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"c\n\x15ListLogGroupsResponse\x12\x31\n\x06groups\x18\x01 \x03(\x0b\x32!.yandex.cloud.logging.v1.LogGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9c\x03\n\x15\x43reateLogGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x33\n\x10retention_period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x0b\x64\x61ta_stream\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x16\x43reateLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\"\xd0\x03\n\x15UpdateLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x33\n\x10retention_period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x0b\x64\x61ta_stream\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x16UpdateLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\";\n\x15\x44\x65leteLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\".\n\x16\x44\x65leteLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\"S\n\x14ListResourcesRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x17\n\x04type\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\"U\n\x15ListResourcesResponse\x12<\n\tresources\x18\x01 \x03(\x0b\x32).yandex.cloud.logging.v1.LogGroupResource\"\x95\x01\n\x15ListOperationsRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x18GetLogGroupStatsResponse\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\x12\r\n\x05\x62ytes\x18\x02 \x01(\x03\x12\x0f\n\x07records\x18\x03 \x01(\x03\x32\xc8\x0f\n\x0fLogGroupService\x12\x83\x01\n\x03Get\x12+.yandex.cloud.logging.v1.GetLogGroupRequest\x1a!.yandex.cloud.logging.v1.LogGroup\",\x82\xd3\xe4\x93\x02&\x12$/logging/v1/logGroups/{log_group_id}\x12\xa0\x01\n\x05Stats\x12\x30.yandex.cloud.logging.v1.GetLogGroupStatsRequest\x1a\x31.yandex.cloud.logging.v1.GetLogGroupStatsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/logging/v1/logGroups/{log_group_id}/stats\x12\x84\x01\n\x04List\x12-.yandex.cloud.logging.v1.ListLogGroupsRequest\x1a..yandex.cloud.logging.v1.ListLogGroupsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/logging/v1/logGroups\x12\xa3\x01\n\x06\x43reate\x12..yandex.cloud.logging.v1.CreateLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2*\"\n\x16\x43reateLogGroupMetadata\x12\x08LogGroup\x82\xd3\xe4\x93\x02\x1a\"\x15/logging/v1/logGroups:\x01*\x12\xb2\x01\n\x06Update\x12..yandex.cloud.logging.v1.UpdateLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\"\n\x16UpdateLogGroupMetadata\x12\x08LogGroup\x82\xd3\xe4\x93\x02)2$/logging/v1/logGroups/{log_group_id}:\x01*\x12\xbc\x01\n\x06\x44\x65lete\x12..yandex.cloud.logging.v1.DeleteLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*/\n\x16\x44\x65leteLogGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/logging/v1/logGroups/{log_group_id}\x12\xaa\x01\n\rListResources\x12-.yandex.cloud.logging.v1.ListResourcesRequest\x1a..yandex.cloud.logging.v1.ListResourcesResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/logging/v1/logGroups/{log_group_id}:listResources\x12\xaa\x01\n\x0eListOperations\x12..yandex.cloud.logging.v1.ListOperationsRequest\x1a/.yandex.cloud.logging.v1.ListOperationsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//logging/v1/logGroups/{log_group_id}/operations\x12\xb5\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/logging/v1/logGroups/{resource_id}:listAccessBindings\x12\xe4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02:\"5/logging/v1/logGroups/{resource_id}:setAccessBindings:\x01*\x12\xf1\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=28/logging/v1/logGroups/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.log_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _GETLOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
  _GETLOGGROUPREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _GETLOGGROUPSTATSREQUEST.fields_by_name['log_group_id']._options = None
  _GETLOGGROUPSTATSREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTLOGGROUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTLOGGROUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTLOGGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTLOGGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTLOGGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTLOGGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATELOGGROUPREQUEST_LABELSENTRY._options = None
  _CREATELOGGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATELOGGROUPREQUEST.fields_by_name['folder_id']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _CREATELOGGROUPREQUEST.fields_by_name['name']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?'
  _CREATELOGGROUPREQUEST.fields_by_name['description']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATELOGGROUPREQUEST.fields_by_name['labels']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATELOGGROUPREQUEST.fields_by_name['data_stream']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['data_stream']._serialized_options = b'\212\3101\005<=512'
  _UPDATELOGGROUPREQUEST_LABELSENTRY._options = None
  _UPDATELOGGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATELOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _UPDATELOGGROUPREQUEST.fields_by_name['name']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?'
  _UPDATELOGGROUPREQUEST.fields_by_name['description']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATELOGGROUPREQUEST.fields_by_name['labels']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATELOGGROUPREQUEST.fields_by_name['data_stream']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['data_stream']._serialized_options = b'\212\3101\005<=512'
  _DELETELOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
  _DELETELOGGROUPREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTRESOURCESREQUEST.fields_by_name['log_group_id']._options = None
  _LISTRESOURCESREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTRESOURCESREQUEST.fields_by_name['type']._options = None
  _LISTRESOURCESREQUEST.fields_by_name['type']._serialized_options = b'\212\3101\005<=256'
  _LISTOPERATIONSREQUEST.fields_by_name['log_group_id']._options = None
  _LISTOPERATIONSREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTOPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTOPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LOGGROUPSERVICE.methods_by_name['Get']._options = None
  _LOGGROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/logging/v1/logGroups/{log_group_id}'
  _LOGGROUPSERVICE.methods_by_name['Stats']._options = None
  _LOGGROUPSERVICE.methods_by_name['Stats']._serialized_options = b'\202\323\344\223\002,\022*/logging/v1/logGroups/{log_group_id}/stats'
  _LOGGROUPSERVICE.methods_by_name['List']._options = None
  _LOGGROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/logging/v1/logGroups'
  _LOGGROUPSERVICE.methods_by_name['Create']._options = None
  _LOGGROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateLogGroupMetadata\022\010LogGroup\202\323\344\223\002\032\"\025/logging/v1/logGroups:\001*'
  _LOGGROUPSERVICE.methods_by_name['Update']._options = None
  _LOGGROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateLogGroupMetadata\022\010LogGroup\202\323\344\223\002)2$/logging/v1/logGroups/{log_group_id}:\001*'
  _LOGGROUPSERVICE.methods_by_name['Delete']._options = None
  _LOGGROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteLogGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/logging/v1/logGroups/{log_group_id}'
  _LOGGROUPSERVICE.methods_by_name['ListResources']._options = None
  _LOGGROUPSERVICE.methods_by_name['ListResources']._serialized_options = b'\202\323\344\223\0024\0222/logging/v1/logGroups/{log_group_id}:listResources'
  _LOGGROUPSERVICE.methods_by_name['ListOperations']._options = None
  _LOGGROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0021\022//logging/v1/logGroups/{log_group_id}/operations'
  _LOGGROUPSERVICE.methods_by_name['ListAccessBindings']._options = None
  _LOGGROUPSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0028\0226/logging/v1/logGroups/{resource_id}:listAccessBindings'
  _LOGGROUPSERVICE.methods_by_name['SetAccessBindings']._options = None
  _LOGGROUPSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002:\"5/logging/v1/logGroups/{resource_id}:setAccessBindings:\001*'
  _LOGGROUPSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _LOGGROUPSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002=28/logging/v1/logGroups/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETLOGGROUPREQUEST']._serialized_start=396
  _globals['_GETLOGGROUPREQUEST']._serialized_end=452
  _globals['_GETLOGGROUPSTATSREQUEST']._serialized_start=454
  _globals['_GETLOGGROUPSTATSREQUEST']._serialized_end=515
  _globals['_LISTLOGGROUPSREQUEST']._serialized_start=518
  _globals['_LISTLOGGROUPSREQUEST']._serialized_end=651
  _globals['_LISTLOGGROUPSRESPONSE']._serialized_start=653
  _globals['_LISTLOGGROUPSRESPONSE']._serialized_end=752
  _globals['_CREATELOGGROUPREQUEST']._serialized_start=755
  _globals['_CREATELOGGROUPREQUEST']._serialized_end=1167
  _globals['_CREATELOGGROUPREQUEST_LABELSENTRY']._serialized_start=1122
  _globals['_CREATELOGGROUPREQUEST_LABELSENTRY']._serialized_end=1167
  _globals['_CREATELOGGROUPMETADATA']._serialized_start=1169
  _globals['_CREATELOGGROUPMETADATA']._serialized_end=1215
  _globals['_UPDATELOGGROUPREQUEST']._serialized_start=1218
  _globals['_UPDATELOGGROUPREQUEST']._serialized_end=1682
  _globals['_UPDATELOGGROUPREQUEST_LABELSENTRY']._serialized_start=1122
  _globals['_UPDATELOGGROUPREQUEST_LABELSENTRY']._serialized_end=1167
  _globals['_UPDATELOGGROUPMETADATA']._serialized_start=1684
  _globals['_UPDATELOGGROUPMETADATA']._serialized_end=1730
  _globals['_DELETELOGGROUPREQUEST']._serialized_start=1732
  _globals['_DELETELOGGROUPREQUEST']._serialized_end=1791
  _globals['_DELETELOGGROUPMETADATA']._serialized_start=1793
  _globals['_DELETELOGGROUPMETADATA']._serialized_end=1839
  _globals['_LISTRESOURCESREQUEST']._serialized_start=1841
  _globals['_LISTRESOURCESREQUEST']._serialized_end=1924
  _globals['_LISTRESOURCESRESPONSE']._serialized_start=1926
  _globals['_LISTRESOURCESRESPONSE']._serialized_end=2011
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=2014
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=2163
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=2165
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=2269
  _globals['_GETLOGGROUPSTATSRESPONSE']._serialized_start=2271
  _globals['_GETLOGGROUPSTATSRESPONSE']._serialized_end=2351
  _globals['_LOGGROUPSERVICE']._serialized_start=2354
  _globals['_LOGGROUPSERVICE']._serialized_end=4346
# @@protoc_insertion_point(module_scope)
