"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AsymmetricDecryptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    CIPHERTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to use for decryption."""
    ciphertext: builtins.bytes
    """Ciphertext to be decrypted.
    Should be encoded with base64.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        ciphertext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ciphertext", b"ciphertext", "key_id", b"key_id"]) -> None: ...

global___AsymmetricDecryptRequest = AsymmetricDecryptRequest

@typing.final
class AsymmetricDecryptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PLAINTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key that was used for decryption."""
    plaintext: builtins.bytes
    """Decrypted plaintext."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        plaintext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "plaintext", b"plaintext"]) -> None: ...

global___AsymmetricDecryptResponse = AsymmetricDecryptResponse

@typing.final
class AsymmetricGetPublicKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to be used for public key retrieval."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___AsymmetricGetPublicKeyRequest = AsymmetricGetPublicKeyRequest

@typing.final
class AsymmetricGetPublicKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to get public key of."""
    public_key: builtins.str
    """Public key value.
    The value is a PEM-encoded X.509 public key, also known as SubjectPublicKeyInfo (SPKI),
    as defined in RFC 5280.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        public_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "public_key", b"public_key"]) -> None: ...

global___AsymmetricGetPublicKeyResponse = AsymmetricGetPublicKeyResponse
