# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.cloudregistry.v1 import registry_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2
from yandex.cloud.cloudregistry.v1 import registry_service_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class RegistryServiceStub(object):
    """A set of methods for managing Registry resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/Get',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.GetRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2.Registry.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/List',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/Create',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.CreateRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/Update',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/Delete',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.DeleteRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListIpPermissions = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/ListIpPermissions',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsResponse.FromString,
                )
        self.SetIpPermissions = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/SetIpPermissions',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.SetIpPermissionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateIpPermissions = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/UpdateIpPermissions',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateIpPermissionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListArtifacts = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/ListArtifacts',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsResponse.FromString,
                )


class RegistryServiceServicer(object):
    """A set of methods for managing Registry resources.
    """

    def Get(self, request, context):
        """Returns the specified Registry resource.

        To get the list of available Registry resources, make a [RegistryService.List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Registry resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a registry in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """access

        Lists access bindings for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIpPermissions(self, request, context):
        """List ip permissions for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetIpPermissions(self, request, context):
        """Set ip permissions for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateIpPermissions(self, request, context):
        """Update ip permissions for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListArtifacts(self, request, context):
        """Retrieves the list of registry artifact resources in the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RegistryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.GetRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2.Registry.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.CreateRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.DeleteRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListIpPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIpPermissions,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsResponse.SerializeToString,
            ),
            'SetIpPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.SetIpPermissions,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.SetIpPermissionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateIpPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateIpPermissions,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateIpPermissionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListArtifacts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListArtifacts,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.cloudregistry.v1.RegistryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RegistryService(object):
    """A set of methods for managing Registry resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/Get',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.GetRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2.Registry.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/List',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/Create',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.CreateRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/Update',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/Delete',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.DeleteRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListIpPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/ListIpPermissions',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetIpPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/SetIpPermissions',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.SetIpPermissionsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateIpPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/UpdateIpPermissions',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateIpPermissionsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListArtifacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/ListArtifacts',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
