# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.k8s.marketplace.v1 import helm_release_pb2 as yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__pb2
from yandex.cloud.k8s.marketplace.v1 import helm_release_service_pb2 as yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class HelmReleaseServiceStub(object):
    """A set of methods for managing Helm release.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/List',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Get',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.GetHelmReleaseRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__pb2.HelmRelease.FromString,
                )
        self.Install = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Install',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.InstallHelmReleaseRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Update',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UpdateHelmReleaseRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Uninstall = channel.unary_unary(
                '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Uninstall',
                request_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UninstallHelmReleaseRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class HelmReleaseServiceServicer(object):
    """A set of methods for managing Helm release.
    """

    def List(self, request, context):
        """Retrieves the list of Helm releases in the specified Kubernetes Cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the specified Helm release.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Install(self, request, context):
        """Installs helm release into specified Kubernetes Cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates helm release.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Uninstall(self, request, context):
        """Uninstalls helm release.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HelmReleaseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.GetHelmReleaseRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__pb2.HelmRelease.SerializeToString,
            ),
            'Install': grpc.unary_unary_rpc_method_handler(
                    servicer.Install,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.InstallHelmReleaseRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UpdateHelmReleaseRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Uninstall': grpc.unary_unary_rpc_method_handler(
                    servicer.Uninstall,
                    request_deserializer=yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UninstallHelmReleaseRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.k8s.marketplace.v1.HelmReleaseService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HelmReleaseService(object):
    """A set of methods for managing Helm release.
    """

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/List',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesRequest.SerializeToString,
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.ListHelmReleasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Get',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.GetHelmReleaseRequest.SerializeToString,
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__pb2.HelmRelease.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Install(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Install',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.InstallHelmReleaseRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Update',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UpdateHelmReleaseRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Uninstall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.k8s.marketplace.v1.HelmReleaseService/Uninstall',
            yandex_dot_cloud_dot_k8s_dot_marketplace_dot_v1_dot_helm__release__service__pb2.UninstallHelmReleaseRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
