# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tuning/v1/tuning_schedulers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/ai/tuning/v1/tuning_schedulers.proto\x12\x19yandex.cloud.ai.tuning.v1\"!\n\x0fSchedulerLinear\x12\x0e\n\x06min_lr\x18\x01 \x01(\x01\"\x13\n\x11SchedulerConstant\"!\n\x0fSchedulerCosine\x12\x0e\n\x06min_lr\x18\x01 \x01(\x01\x42\x63\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_schedulers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _globals['_SCHEDULERLINEAR']._serialized_start=80
  _globals['_SCHEDULERLINEAR']._serialized_end=113
  _globals['_SCHEDULERCONSTANT']._serialized_start=115
  _globals['_SCHEDULERCONSTANT']._serialized_end=134
  _globals['_SCHEDULERCOSINE']._serialized_start=136
  _globals['_SCHEDULERCOSINE']._serialized_end=169
# @@protoc_insertion_point(module_scope)
