"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.backup.v1.provider_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ProviderServiceStub:
    """A set of methods for managing [backup providers](/docs/backup/concepts/#providers)."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Activate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.provider_service_pb2.ActivateProviderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activate provider for specified client."""

    ListActivated: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersRequest,
        yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersResponse,
    ]
    """List activated providers for specified client."""

class ProviderServiceAsyncStub:
    """A set of methods for managing [backup providers](/docs/backup/concepts/#providers)."""

    Activate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.provider_service_pb2.ActivateProviderRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Activate provider for specified client."""

    ListActivated: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersRequest,
        yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersResponse,
    ]
    """List activated providers for specified client."""

class ProviderServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing [backup providers](/docs/backup/concepts/#providers)."""

    @abc.abstractmethod
    def Activate(
        self,
        request: yandex.cloud.backup.v1.provider_service_pb2.ActivateProviderRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Activate provider for specified client."""

    @abc.abstractmethod
    def ListActivated(
        self,
        request: yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersResponse, collections.abc.Awaitable[yandex.cloud.backup.v1.provider_service_pb2.ListActivatedProvidersResponse]]:
        """List activated providers for specified client."""

def add_ProviderServiceServicer_to_server(servicer: ProviderServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
