# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/tuning/v1/tuning_types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/ai/tuning/v1/tuning_types.proto\x12\x19yandex.cloud.ai.tuning.v1\"S\n\x0eTuningTypeLora\x12\x0c\n\x04rank\x18\x01 \x01(\x03\x12\r\n\x05\x61lpha\x18\x02 \x01(\x01\x12\x16\n\x0einitialization\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\".\n\x14TuningTypePromptTune\x12\x16\n\x0evirtual_tokens\x18\x01 \x01(\x03\x42\x63\n\x1dyandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.tuning.v1.tuning_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.tuning.v1ZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/tuning/v1;fomo'
  _globals['_TUNINGTYPELORA']._serialized_start=75
  _globals['_TUNINGTYPELORA']._serialized_end=158
  _globals['_TUNINGTYPEPROMPTTUNE']._serialized_start=160
  _globals['_TUNINGTYPEPROMPTTUNE']._serialized_end=206
# @@protoc_insertion_point(module_scope)
