"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.analysis.statistics_common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InterruptsStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEAKER_INTERRUPTS_FIELD_NUMBER: builtins.int
    @property
    def speaker_interrupts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InterruptsEvaluation]:
        """Interrupts description for every speaker"""

    def __init__(
        self,
        *,
        speaker_interrupts: collections.abc.Iterable[global___InterruptsEvaluation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["speaker_interrupts", b"speaker_interrupts"]) -> None: ...

global___InterruptsStatistics = InterruptsStatistics

@typing.final
class InterruptsEvaluation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEAKER_TAG_FIELD_NUMBER: builtins.int
    INTERRUPTS_COUNT_FIELD_NUMBER: builtins.int
    INTERRUPTS_DURATION_MS_FIELD_NUMBER: builtins.int
    INTERRUPTS_FIELD_NUMBER: builtins.int
    INTERRUPTS_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    speaker_tag: builtins.str
    """Speaker tag"""
    interrupts_count: builtins.int
    """Number of interrupts made by the speaker"""
    interrupts_duration_ms: builtins.int
    """Total duration of all interrupts"""
    interrupts_duration_seconds: builtins.int
    """Total duration of all interrupts in seconds"""
    @property
    def interrupts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries]:
        """Boundaries for every interrupt"""

    def __init__(
        self,
        *,
        speaker_tag: builtins.str = ...,
        interrupts_count: builtins.int = ...,
        interrupts_duration_ms: builtins.int = ...,
        interrupts: collections.abc.Iterable[yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries] | None = ...,
        interrupts_duration_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["interrupts", b"interrupts", "interrupts_count", b"interrupts_count", "interrupts_duration_ms", b"interrupts_duration_ms", "interrupts_duration_seconds", b"interrupts_duration_seconds", "speaker_tag", b"speaker_tag"]) -> None: ...

global___InterruptsEvaluation = InterruptsEvaluation
