# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/workload/oidc/federation_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1.workload.oidc import federation_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_workload_dot_oidc_dot_federation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/iam/v1/workload/oidc/federation_service.proto\x12!yandex.cloud.iam.v1.workload.oidc\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x32yandex/cloud/iam/v1/workload/oidc/federation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\";\n\x14GetFederationRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"x\n\x16ListFederationsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"v\n\x17ListFederationsResponse\x12\x42\n\x0b\x66\x65\x64\x65rations\x18\x01 \x03(\x0b\x32-.yandex.cloud.iam.v1.workload.oidc.Federation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x93\x03\n\x17\x43reateFederationRequest\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x04name\x18\x03 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x12%\n\taudiences\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=100\x8a\xc8\x31\x05<=255\x12\x1e\n\x06issuer\x18\x07 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12 \n\x08jwks_url\x18\x08 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12V\n\x06labels\x18\t \x03(\x0b\x32\x46.yandex.cloud.iam.v1.workload.oidc.CreateFederationRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18\x43reateFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\xa0\x03\n\x17UpdateFederationRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x04name\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x12%\n\taudiences\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=100\x8a\xc8\x31\x05<=255\x12\x1c\n\x08jwks_url\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=8000\x12V\n\x06labels\x18\x08 \x03(\x0b\x32\x46.yandex.cloud.iam.v1.workload.oidc.UpdateFederationRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18UpdateFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\">\n\x17\x44\x65leteFederationRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"1\n\x18\x44\x65leteFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t2\xd7\x07\n\x11\x46\x65\x64\x65rationService\x12\xa8\x01\n\x03Get\x12\x37.yandex.cloud.iam.v1.workload.oidc.GetFederationRequest\x1a-.yandex.cloud.iam.v1.workload.oidc.Federation\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/iam/v1/workload/oidc/federations/{federation_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.iam.v1.workload.oidc.ListFederationsRequest\x1a:.yandex.cloud.iam.v1.workload.oidc.ListFederationsResponse\")\x82\xd3\xe4\x93\x02#\x12!/iam/v1/workload/oidc/federations\x12\xbf\x01\n\x06\x43reate\x12:.yandex.cloud.iam.v1.workload.oidc.CreateFederationRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*&\n\x18\x43reateFederationMetadata\x12\nFederation\x82\xd3\xe4\x93\x02&\"!/iam/v1/workload/oidc/federations:\x01*\x12\xcf\x01\n\x06Update\x12:.yandex.cloud.iam.v1.workload.oidc.UpdateFederationRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*&\n\x18UpdateFederationMetadata\x12\nFederation\x82\xd3\xe4\x93\x02\x36\x32\x31/iam/v1/workload/oidc/federations/{federation_id}:\x01*\x12\xd7\x01\n\x06\x44\x65lete\x12:.yandex.cloud.iam.v1.workload.oidc.DeleteFederationRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*1\n\x18\x44\x65leteFederationMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x33*1/iam/v1/workload/oidc/federations/{federation_id}Bs\n%yandex.cloud.api.iam.v1.workload.oidcZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload/oidc;oidcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.workload.oidc.federation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.iam.v1.workload.oidcZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload/oidc;oidc'
  _GETFEDERATIONREQUEST.fields_by_name['federation_id']._options = None
  _GETFEDERATIONREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFEDERATIONSREQUEST.fields_by_name['folder_id']._options = None
  _LISTFEDERATIONSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFEDERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTFEDERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTFEDERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTFEDERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _CREATEFEDERATIONREQUEST_LABELSENTRY._options = None
  _CREATEFEDERATIONREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEFEDERATIONREQUEST.fields_by_name['folder_id']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEFEDERATIONREQUEST.fields_by_name['name']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEFEDERATIONREQUEST.fields_by_name['description']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEFEDERATIONREQUEST.fields_by_name['audiences']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['audiences']._serialized_options = b'\202\3101\005<=100\212\3101\005<=255'
  _CREATEFEDERATIONREQUEST.fields_by_name['issuer']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['issuer']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _CREATEFEDERATIONREQUEST.fields_by_name['jwks_url']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['jwks_url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _UPDATEFEDERATIONREQUEST_LABELSENTRY._options = None
  _UPDATEFEDERATIONREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEFEDERATIONREQUEST.fields_by_name['federation_id']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEFEDERATIONREQUEST.fields_by_name['name']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEFEDERATIONREQUEST.fields_by_name['description']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEFEDERATIONREQUEST.fields_by_name['audiences']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['audiences']._serialized_options = b'\202\3101\005<=100\212\3101\005<=255'
  _UPDATEFEDERATIONREQUEST.fields_by_name['jwks_url']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['jwks_url']._serialized_options = b'\212\3101\006<=8000'
  _DELETEFEDERATIONREQUEST.fields_by_name['federation_id']._options = None
  _DELETEFEDERATIONREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _FEDERATIONSERVICE.methods_by_name['Get']._options = None
  _FEDERATIONSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0023\0221/iam/v1/workload/oidc/federations/{federation_id}'
  _FEDERATIONSERVICE.methods_by_name['List']._options = None
  _FEDERATIONSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/iam/v1/workload/oidc/federations'
  _FEDERATIONSERVICE.methods_by_name['Create']._options = None
  _FEDERATIONSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateFederationMetadata\022\nFederation\202\323\344\223\002&\"!/iam/v1/workload/oidc/federations:\001*'
  _FEDERATIONSERVICE.methods_by_name['Update']._options = None
  _FEDERATIONSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateFederationMetadata\022\nFederation\202\323\344\223\002621/iam/v1/workload/oidc/federations/{federation_id}:\001*'
  _FEDERATIONSERVICE.methods_by_name['Delete']._options = None
  _FEDERATIONSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteFederationMetadata\022\025google.protobuf.Empty\202\323\344\223\0023*1/iam/v1/workload/oidc/federations/{federation_id}'
  _globals['_GETFEDERATIONREQUEST']._serialized_start=318
  _globals['_GETFEDERATIONREQUEST']._serialized_end=377
  _globals['_LISTFEDERATIONSREQUEST']._serialized_start=379
  _globals['_LISTFEDERATIONSREQUEST']._serialized_end=499
  _globals['_LISTFEDERATIONSRESPONSE']._serialized_start=501
  _globals['_LISTFEDERATIONSRESPONSE']._serialized_end=619
  _globals['_CREATEFEDERATIONREQUEST']._serialized_start=622
  _globals['_CREATEFEDERATIONREQUEST']._serialized_end=1025
  _globals['_CREATEFEDERATIONREQUEST_LABELSENTRY']._serialized_start=980
  _globals['_CREATEFEDERATIONREQUEST_LABELSENTRY']._serialized_end=1025
  _globals['_CREATEFEDERATIONMETADATA']._serialized_start=1027
  _globals['_CREATEFEDERATIONMETADATA']._serialized_end=1076
  _globals['_UPDATEFEDERATIONREQUEST']._serialized_start=1079
  _globals['_UPDATEFEDERATIONREQUEST']._serialized_end=1495
  _globals['_UPDATEFEDERATIONREQUEST_LABELSENTRY']._serialized_start=980
  _globals['_UPDATEFEDERATIONREQUEST_LABELSENTRY']._serialized_end=1025
  _globals['_UPDATEFEDERATIONMETADATA']._serialized_start=1497
  _globals['_UPDATEFEDERATIONMETADATA']._serialized_end=1546
  _globals['_DELETEFEDERATIONREQUEST']._serialized_start=1548
  _globals['_DELETEFEDERATIONREQUEST']._serialized_end=1610
  _globals['_DELETEFEDERATIONMETADATA']._serialized_start=1612
  _globals['_DELETEFEDERATIONMETADATA']._serialized_end=1661
  _globals['_FEDERATIONSERVICE']._serialized_start=1664
  _globals['_FEDERATIONSERVICE']._serialized_end=2647
# @@protoc_insertion_point(module_scope)
