"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.monitoring.v3.chart_widget_pb2
import yandex.cloud.monitoring.v3.text_widget_pb2
import yandex.cloud.monitoring.v3.title_widget_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Widget(google.protobuf.message.Message):
    """Widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LayoutPosition(google.protobuf.message.Message):
        """Layout item for widget item positioning."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        X_FIELD_NUMBER: builtins.int
        Y_FIELD_NUMBER: builtins.int
        W_FIELD_NUMBER: builtins.int
        H_FIELD_NUMBER: builtins.int
        x: builtins.int
        """Required. X-axis top-left corner coordinate."""
        y: builtins.int
        """Required. Y-axis top-left corner coordinate."""
        w: builtins.int
        """Required. Weight."""
        h: builtins.int
        """Required. Height."""
        def __init__(
            self,
            *,
            x: builtins.int = ...,
            y: builtins.int = ...,
            w: builtins.int = ...,
            h: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["h", b"h", "w", b"w", "x", b"x", "y", b"y"]) -> None: ...

    POSITION_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CHART_FIELD_NUMBER: builtins.int
    @property
    def position(self) -> global___Widget.LayoutPosition:
        """Required. Widget layout position."""

    @property
    def text(self) -> yandex.cloud.monitoring.v3.text_widget_pb2.TextWidget:
        """Text widget."""

    @property
    def title(self) -> yandex.cloud.monitoring.v3.title_widget_pb2.TitleWidget:
        """Title widget."""

    @property
    def chart(self) -> yandex.cloud.monitoring.v3.chart_widget_pb2.ChartWidget:
        """Chart widget."""

    def __init__(
        self,
        *,
        position: global___Widget.LayoutPosition | None = ...,
        text: yandex.cloud.monitoring.v3.text_widget_pb2.TextWidget | None = ...,
        title: yandex.cloud.monitoring.v3.title_widget_pb2.TitleWidget | None = ...,
        chart: yandex.cloud.monitoring.v3.chart_widget_pb2.ChartWidget | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chart", b"chart", "position", b"position", "text", b"text", "title", b"title", "widget", b"widget"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chart", b"chart", "position", b"position", "text", b"text", "title", b"title", "widget", b"widget"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["widget", b"widget"]) -> typing.Literal["text", "title", "chart"] | None: ...

global___Widget = Widget
