# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/regression_dashboard_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.loadtesting.api.v1.regression import dashboard_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_regression_dot_dashboard__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/loadtesting/api/v1/regression_dashboard_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a:yandex/cloud/loadtesting/api/v1/regression/dashboard.proto\x1a\x1dyandex/cloud/validation.proto\"\xe5\x01\n CreateRegressionDashboardRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12N\n\x07\x63ontent\x18\x04 \x01(\x0b\x32=.yandex.cloud.loadtesting.api.v1.regression.Dashboard.Content\"9\n!CreateRegressionDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"I\n\x1dGetRegressionDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50J\x04\x08\x02\x10\x03\"T\n DeleteRegressionDashboardRequest\x12\"\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\"9\n!DeleteRegressionDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t\"\xa2\x01\n\x1fListRegressionDashboardsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x03\"\x91\x01\n ListRegressionDashboardsResponse\x12I\n\ndashboards\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.loadtesting.api.v1.regression.Dashboard\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x9f\x02\n UpdateRegressionDashboardRequest\x12\x1a\n\x0c\x64\x61shboard_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x04 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1f\n\x0b\x64\x65scription\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12N\n\x07\x63ontent\x18\x06 \x01(\x0b\x32=.yandex.cloud.loadtesting.api.v1.regression.Dashboard.Content\"9\n!UpdateRegressionDashboardMetadata\x12\x14\n\x0c\x64\x61shboard_id\x18\x01 \x01(\t2\xe1\x08\n\x1aRegressionDashboardService\x12\xe0\x01\n\x06\x43reate\x12\x41.yandex.cloud.loadtesting.api.v1.CreateRegressionDashboardRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*9\n!CreateRegressionDashboardMetadata\x12\x14regression.Dashboard\x82\xd3\xe4\x93\x02-\"(/loadtesting/api/v1/regressionDashboards:\x01*\x12\xbd\x01\n\x03Get\x12>.yandex.cloud.loadtesting.api.v1.GetRegressionDashboardRequest\x1a\x35.yandex.cloud.loadtesting.api.v1.regression.Dashboard\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/loadtesting/api/v1/regressionDashboards/{dashboard_id}\x12\xbd\x01\n\x04List\x12@.yandex.cloud.loadtesting.api.v1.ListRegressionDashboardsRequest\x1a\x41.yandex.cloud.loadtesting.api.v1.ListRegressionDashboardsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/loadtesting/api/v1/regressionDashboards\x12\xed\x01\n\x06\x44\x65lete\x12\x41.yandex.cloud.loadtesting.api.v1.DeleteRegressionDashboardRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*:\n!DeleteRegressionDashboardMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x39*7/loadtesting/api/v1/regressionDashboards/{dashboard_id}\x12\xef\x01\n\x06Update\x12\x41.yandex.cloud.loadtesting.api.v1.UpdateRegressionDashboardRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*9\n!UpdateRegressionDashboardMetadata\x12\x14regression.Dashboard\x82\xd3\xe4\x93\x02<27/loadtesting/api/v1/regressionDashboards/{dashboard_id}:\x01*Bv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.regression_dashboard_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting'
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['folder_id']._options = None
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['name']._options = None
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['description']._options = None
  _CREATEREGRESSIONDASHBOARDREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _GETREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
  _GETREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
  _DELETEREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['folder_id']._options = None
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['page_size']._options = None
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['page_token']._options = None
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['filter']._options = None
  _LISTREGRESSIONDASHBOARDSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTREGRESSIONDASHBOARDSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTREGRESSIONDASHBOARDSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=100'
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._options = None
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['dashboard_id']._serialized_options = b'\350\3071\001'
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['name']._options = None
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['description']._options = None
  _UPDATEREGRESSIONDASHBOARDREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Create']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*9\n!CreateRegressionDashboardMetadata\022\024regression.Dashboard\202\323\344\223\002-\"(/loadtesting/api/v1/regressionDashboards:\001*'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Get']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0029\0227/loadtesting/api/v1/regressionDashboards/{dashboard_id}'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['List']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002*\022(/loadtesting/api/v1/regressionDashboards'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Delete']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*:\n!DeleteRegressionDashboardMetadata\022\025google.protobuf.Empty\202\323\344\223\0029*7/loadtesting/api/v1/regressionDashboards/{dashboard_id}'
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Update']._options = None
  _REGRESSIONDASHBOARDSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*9\n!UpdateRegressionDashboardMetadata\022\024regression.Dashboard\202\323\344\223\002<27/loadtesting/api/v1/regressionDashboards/{dashboard_id}:\001*'
  _globals['_CREATEREGRESSIONDASHBOARDREQUEST']._serialized_start=333
  _globals['_CREATEREGRESSIONDASHBOARDREQUEST']._serialized_end=562
  _globals['_CREATEREGRESSIONDASHBOARDMETADATA']._serialized_start=564
  _globals['_CREATEREGRESSIONDASHBOARDMETADATA']._serialized_end=621
  _globals['_GETREGRESSIONDASHBOARDREQUEST']._serialized_start=623
  _globals['_GETREGRESSIONDASHBOARDREQUEST']._serialized_end=696
  _globals['_DELETEREGRESSIONDASHBOARDREQUEST']._serialized_start=698
  _globals['_DELETEREGRESSIONDASHBOARDREQUEST']._serialized_end=782
  _globals['_DELETEREGRESSIONDASHBOARDMETADATA']._serialized_start=784
  _globals['_DELETEREGRESSIONDASHBOARDMETADATA']._serialized_end=841
  _globals['_LISTREGRESSIONDASHBOARDSREQUEST']._serialized_start=844
  _globals['_LISTREGRESSIONDASHBOARDSREQUEST']._serialized_end=1006
  _globals['_LISTREGRESSIONDASHBOARDSRESPONSE']._serialized_start=1009
  _globals['_LISTREGRESSIONDASHBOARDSRESPONSE']._serialized_end=1154
  _globals['_UPDATEREGRESSIONDASHBOARDREQUEST']._serialized_start=1157
  _globals['_UPDATEREGRESSIONDASHBOARDREQUEST']._serialized_end=1444
  _globals['_UPDATEREGRESSIONDASHBOARDMETADATA']._serialized_start=1446
  _globals['_UPDATEREGRESSIONDASHBOARDMETADATA']._serialized_end=1503
  _globals['_REGRESSIONDASHBOARDSERVICE']._serialized_start=1506
  _globals['_REGRESSIONDASHBOARDSERVICE']._serialized_end=2627
# @@protoc_insertion_point(module_scope)
