"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.test.object_storage_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class FilePointer(google.protobuf.message.Message):
    """Variant-like structure for referencing files in different sources."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_STORAGE_FIELD_NUMBER: builtins.int
    @property
    def object_storage(self) -> yandex.cloud.loadtesting.api.v1.test.object_storage_pb2.ObjectStorage:
        """Reference to a file in Object Storage."""

    def __init__(
        self,
        *,
        object_storage: yandex.cloud.loadtesting.api.v1.test.object_storage_pb2.ObjectStorage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["file_pointer", b"file_pointer", "object_storage", b"object_storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["file_pointer", b"file_pointer", "object_storage", b"object_storage"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["file_pointer", b"file_pointer"]) -> typing.Literal["object_storage"] | None: ...

global___FilePointer = FilePointer
