# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/privatelink/private_endpoint_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.vpc.v1.privatelink import private_endpoint_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_privatelink_dot_private__endpoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/vpc/v1/privatelink/private_endpoint_service.proto\x12\x1fyandex.cloud.vpc.v1.privatelink\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x36yandex/cloud/vpc/v1/privatelink/private_endpoint.proto\"F\n\x19GetPrivateEndpointRequest\x12)\n\x13private_endpoint_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"K\n\x17InternalIpv4AddressSpec\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"\x8e\x01\n\x0b\x41\x64\x64ressSpec\x12\x14\n\naddress_id\x18\x01 \x01(\tH\x00\x12^\n\x1ainternal_ipv4_address_spec\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.vpc.v1.privatelink.InternalIpv4AddressSpecH\x00\x42\t\n\x07\x61\x64\x64ress\"\x8c\x05\n\x1c\x43reatePrivateEndpointRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9e\x01\n\x06labels\x18\x04 \x03(\x0b\x32I.yandex.cloud.vpc.v1.privatelink.CreatePrivateEndpointRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12 \n\nnetwork_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x42\n\x0c\x61\x64\x64ress_spec\x18\x06 \x01(\x0b\x32,.yandex.cloud.vpc.v1.privatelink.AddressSpec\x12P\n\x0b\x64ns_options\x18\x08 \x01(\x0b\x32;.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.DnsOptions\x12X\n\x0eobject_storage\x18\t \x01(\x0b\x32>.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.ObjectStorageH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\x07service\x12\x04\xc0\xc1\x31\x01J\x04\x08\x07\x10\x08\"<\n\x1d\x43reatePrivateEndpointMetadata\x12\x1b\n\x13private_endpoint_id\x18\x01 \x01(\t\"\xba\x04\n\x1cUpdatePrivateEndpointRequest\x12)\n\x13private_endpoint_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9e\x01\n\x06labels\x18\x05 \x03(\x0b\x32I.yandex.cloud.vpc.v1.privatelink.UpdatePrivateEndpointRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x42\n\x0c\x61\x64\x64ress_spec\x18\x06 \x01(\x0b\x32,.yandex.cloud.vpc.v1.privatelink.AddressSpec\x12P\n\x0b\x64ns_options\x18\x08 \x01(\x0b\x32;.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.DnsOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"<\n\x1dUpdatePrivateEndpointMetadata\x12\x1b\n\x13private_endpoint_id\x18\x01 \x01(\t\"I\n\x1c\x44\x65letePrivateEndpointRequest\x12)\n\x13private_endpoint_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x1d\x44\x65letePrivateEndpointMetadata\x12\x1b\n\x13private_endpoint_id\x18\x01 \x01(\t\"\xb0\x01\n\x1bListPrivateEndpointsRequest\x12\x1d\n\tfolder_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000B\x11\n\tcontainer\x12\x04\xc0\xc1\x31\x01J\x04\x08\x02\x10\x03\"\x84\x01\n\x1cListPrivateEndpointsResponse\x12K\n\x11private_endpoints\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x90\x01\n$ListPrivateEndpointOperationsRequest\x12)\n\x13private_endpoint_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"w\n%ListPrivateEndpointOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xaa\t\n\x16PrivateEndpointService\x12\xa4\x01\n\x03Get\x12:.yandex.cloud.vpc.v1.privatelink.GetPrivateEndpointRequest\x1a\x30.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint\"/\x82\xd3\xe4\x93\x02)\x12\'/vpc/v1/endpoints/{private_endpoint_id}\x12\x9e\x01\n\x04List\x12<.yandex.cloud.vpc.v1.privatelink.ListPrivateEndpointsRequest\x1a=.yandex.cloud.vpc.v1.privatelink.ListPrivateEndpointsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/vpc/v1/endpoints\x12\xbc\x01\n\x06\x43reate\x12=.yandex.cloud.vpc.v1.privatelink.CreatePrivateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*0\n\x1d\x43reatePrivateEndpointMetadata\x12\x0fPrivateEndpoint\x82\xd3\xe4\x93\x02\x16\"\x11/vpc/v1/endpoints:\x01*\x12\xd2\x01\n\x06Update\x12=.yandex.cloud.vpc.v1.privatelink.UpdatePrivateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*0\n\x1dUpdatePrivateEndpointMetadata\x12\x0fPrivateEndpoint\x82\xd3\xe4\x93\x02,2\'/vpc/v1/endpoints/{private_endpoint_id}:\x01*\x12\xd5\x01\n\x06\x44\x65lete\x12=.yandex.cloud.vpc.v1.privatelink.DeletePrivateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*6\n\x1d\x44\x65letePrivateEndpointMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/vpc/v1/endpoints/{private_endpoint_id}\x12\xdb\x01\n\x0eListOperations\x12\x45.yandex.cloud.vpc.v1.privatelink.ListPrivateEndpointOperationsRequest\x1a\x46.yandex.cloud.vpc.v1.privatelink.ListPrivateEndpointOperationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/vpc/v1/endpoints/{private_endpoint_id}/operationsBv\n#yandex.cloud.api.vpc.v1.privatelinkZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1/privatelink;privatelinkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.privatelink.private_endpoint_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.vpc.v1.privatelinkZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1/privatelink;privatelink'
  _GETPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._options = None
  _GETPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _INTERNALIPV4ADDRESSSPEC.fields_by_name['subnet_id']._options = None
  _INTERNALIPV4ADDRESSSPEC.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEPRIVATEENDPOINTREQUEST_LABELSENTRY._options = None
  _CREATEPRIVATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEPRIVATEENDPOINTREQUEST.oneofs_by_name['service']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.oneofs_by_name['service']._serialized_options = b'\300\3011\001'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['folder_id']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['name']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['description']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['labels']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['network_id']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEPRIVATEENDPOINTREQUEST_LABELSENTRY._options = None
  _UPDATEPRIVATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._options = None
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['name']._options = None
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['description']._options = None
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['labels']._options = None
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _DELETEPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._options = None
  _DELETEPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPRIVATEENDPOINTSREQUEST.oneofs_by_name['container']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.oneofs_by_name['container']._serialized_options = b'\300\3011\001'
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['folder_id']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['page_size']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['page_token']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['filter']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['private_endpoint_id']._options = None
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['private_endpoint_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _PRIVATEENDPOINTSERVICE.methods_by_name['Get']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/vpc/v1/endpoints/{private_endpoint_id}'
  _PRIVATEENDPOINTSERVICE.methods_by_name['List']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/vpc/v1/endpoints'
  _PRIVATEENDPOINTSERVICE.methods_by_name['Create']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreatePrivateEndpointMetadata\022\017PrivateEndpoint\202\323\344\223\002\026\"\021/vpc/v1/endpoints:\001*'
  _PRIVATEENDPOINTSERVICE.methods_by_name['Update']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdatePrivateEndpointMetadata\022\017PrivateEndpoint\202\323\344\223\002,2\'/vpc/v1/endpoints/{private_endpoint_id}:\001*'
  _PRIVATEENDPOINTSERVICE.methods_by_name['Delete']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeletePrivateEndpointMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/vpc/v1/endpoints/{private_endpoint_id}'
  _PRIVATEENDPOINTSERVICE.methods_by_name['ListOperations']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0024\0222/vpc/v1/endpoints/{private_endpoint_id}/operations'
  _globals['_GETPRIVATEENDPOINTREQUEST']._serialized_start=324
  _globals['_GETPRIVATEENDPOINTREQUEST']._serialized_end=394
  _globals['_INTERNALIPV4ADDRESSSPEC']._serialized_start=396
  _globals['_INTERNALIPV4ADDRESSSPEC']._serialized_end=471
  _globals['_ADDRESSSPEC']._serialized_start=474
  _globals['_ADDRESSSPEC']._serialized_end=616
  _globals['_CREATEPRIVATEENDPOINTREQUEST']._serialized_start=619
  _globals['_CREATEPRIVATEENDPOINTREQUEST']._serialized_end=1271
  _globals['_CREATEPRIVATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=1203
  _globals['_CREATEPRIVATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=1248
  _globals['_CREATEPRIVATEENDPOINTMETADATA']._serialized_start=1273
  _globals['_CREATEPRIVATEENDPOINTMETADATA']._serialized_end=1333
  _globals['_UPDATEPRIVATEENDPOINTREQUEST']._serialized_start=1336
  _globals['_UPDATEPRIVATEENDPOINTREQUEST']._serialized_end=1906
  _globals['_UPDATEPRIVATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=1203
  _globals['_UPDATEPRIVATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=1248
  _globals['_UPDATEPRIVATEENDPOINTMETADATA']._serialized_start=1908
  _globals['_UPDATEPRIVATEENDPOINTMETADATA']._serialized_end=1968
  _globals['_DELETEPRIVATEENDPOINTREQUEST']._serialized_start=1970
  _globals['_DELETEPRIVATEENDPOINTREQUEST']._serialized_end=2043
  _globals['_DELETEPRIVATEENDPOINTMETADATA']._serialized_start=2045
  _globals['_DELETEPRIVATEENDPOINTMETADATA']._serialized_end=2105
  _globals['_LISTPRIVATEENDPOINTSREQUEST']._serialized_start=2108
  _globals['_LISTPRIVATEENDPOINTSREQUEST']._serialized_end=2284
  _globals['_LISTPRIVATEENDPOINTSRESPONSE']._serialized_start=2287
  _globals['_LISTPRIVATEENDPOINTSRESPONSE']._serialized_end=2419
  _globals['_LISTPRIVATEENDPOINTOPERATIONSREQUEST']._serialized_start=2422
  _globals['_LISTPRIVATEENDPOINTOPERATIONSREQUEST']._serialized_end=2566
  _globals['_LISTPRIVATEENDPOINTOPERATIONSRESPONSE']._serialized_start=2568
  _globals['_LISTPRIVATEENDPOINTOPERATIONSRESPONSE']._serialized_end=2687
  _globals['_PRIVATEENDPOINTSERVICE']._serialized_start=2690
  _globals['_PRIVATEENDPOINTSERVICE']._serialized_end=3884
# @@protoc_insertion_point(module_scope)
