# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.datatransfer.v1 import endpoint_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/datatransfer/v1/endpoint_service.proto\x12\x1cyandex.cloud.datatransfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a+yandex/cloud/datatransfer/v1/endpoint.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\")\n\x12GetEndpointRequest\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t\"P\n\x14ListEndpointsRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"k\n\x15ListEndpointsResponse\x12\x39\n\tendpoints\x18\x01 \x03(\x0b\x32&.yandex.cloud.datatransfer.v1.Endpoint\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x95\x02\n\x15\x43reateEndpointRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12O\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.datatransfer.v1.CreateEndpointRequest.LabelsEntry\x12@\n\x08settings\x18\x34 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.EndpointSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x34\"-\n\x16\x43reateEndpointMetadata\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t\"\xd4\x02\n\x15UpdateEndpointRequest\x12\x13\n\x0b\x65ndpoint_id\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12O\n\x06labels\x18\r \x03(\x0b\x32?.yandex.cloud.datatransfer.v1.UpdateEndpointRequest.LabelsEntry\x12@\n\x08settings\x18\x34 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.EndpointSettings\x12/\n\x0bupdate_mask\x18< \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x01\x10\nJ\x04\x08\x0e\x10\x34J\x04\x08\x35\x10<\"-\n\x16UpdateEndpointMetadata\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t\",\n\x15\x44\x65leteEndpointRequest\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t\"-\n\x16\x44\x65leteEndpointMetadata\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t2\xbd\x06\n\x0f\x45ndpointService\x12\x83\x01\n\x03Get\x12\x30.yandex.cloud.datatransfer.v1.GetEndpointRequest\x1a&.yandex.cloud.datatransfer.v1.Endpoint\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/endpoint/{endpoint_id}\x12\x97\x01\n\x04List\x12\x32.yandex.cloud.datatransfer.v1.ListEndpointsRequest\x1a\x33.yandex.cloud.datatransfer.v1.ListEndpointsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/endpoints/list/{folder_id}\x12\x9f\x01\n\x06\x43reate\x12\x33.yandex.cloud.datatransfer.v1.CreateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"=\xb2\xd2*\"\n\x16\x43reateEndpointMetadata\x12\x08\x45ndpoint\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/endpoint:\x01*\x12\xad\x01\n\x06Update\x12\x33.yandex.cloud.datatransfer.v1.UpdateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*\"\n\x16UpdateEndpointMetadata\x12\x08\x45ndpoint\x82\xd3\xe4\x93\x02\x1f\x32\x1a/v1/endpoint/{endpoint_id}:\x01*\x12\xb7\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.datatransfer.v1.DeleteEndpointRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*/\n\x16\x44\x65leteEndpointMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/endpoint/{endpoint_id}Bq\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransfer'
  _CREATEENDPOINTREQUEST_LABELSENTRY._options = None
  _CREATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEENDPOINTREQUEST_LABELSENTRY._options = None
  _UPDATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _ENDPOINTSERVICE.methods_by_name['Get']._options = None
  _ENDPOINTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/endpoint/{endpoint_id}'
  _ENDPOINTSERVICE.methods_by_name['List']._options = None
  _ENDPOINTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002 \022\036/v1/endpoints/list/{folder_id}'
  _ENDPOINTSERVICE.methods_by_name['Create']._options = None
  _ENDPOINTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateEndpointMetadata\022\010Endpoint\202\323\344\223\002\021\"\014/v1/endpoint:\001*'
  _ENDPOINTSERVICE.methods_by_name['Update']._options = None
  _ENDPOINTSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateEndpointMetadata\022\010Endpoint\202\323\344\223\002\0372\032/v1/endpoint/{endpoint_id}:\001*'
  _ENDPOINTSERVICE.methods_by_name['Delete']._options = None
  _ENDPOINTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteEndpointMetadata\022\025google.protobuf.Empty\202\323\344\223\002\034*\032/v1/endpoint/{endpoint_id}'
  _globals['_GETENDPOINTREQUEST']._serialized_start=268
  _globals['_GETENDPOINTREQUEST']._serialized_end=309
  _globals['_LISTENDPOINTSREQUEST']._serialized_start=311
  _globals['_LISTENDPOINTSREQUEST']._serialized_end=391
  _globals['_LISTENDPOINTSRESPONSE']._serialized_start=393
  _globals['_LISTENDPOINTSRESPONSE']._serialized_end=500
  _globals['_CREATEENDPOINTREQUEST']._serialized_start=503
  _globals['_CREATEENDPOINTREQUEST']._serialized_end=780
  _globals['_CREATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=729
  _globals['_CREATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=774
  _globals['_CREATEENDPOINTMETADATA']._serialized_start=782
  _globals['_CREATEENDPOINTMETADATA']._serialized_end=827
  _globals['_UPDATEENDPOINTREQUEST']._serialized_start=830
  _globals['_UPDATEENDPOINTREQUEST']._serialized_end=1170
  _globals['_UPDATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=729
  _globals['_UPDATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=774
  _globals['_UPDATEENDPOINTMETADATA']._serialized_start=1172
  _globals['_UPDATEENDPOINTMETADATA']._serialized_end=1217
  _globals['_DELETEENDPOINTREQUEST']._serialized_start=1219
  _globals['_DELETEENDPOINTREQUEST']._serialized_end=1263
  _globals['_DELETEENDPOINTMETADATA']._serialized_start=1265
  _globals['_DELETEENDPOINTMETADATA']._serialized_end=1310
  _globals['_ENDPOINTSERVICE']._serialized_start=1313
  _globals['_ENDPOINTSERVICE']._serialized_end=2142
# @@protoc_insertion_point(module_scope)
