"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.loadtesting.api.v1.report_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ReportServiceStub:
    """A set of methods for managing test reports."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetTable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportRequest,
        yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportResponse,
    ]
    """Returns a report table for the specified test."""

    CalculateKpiValues: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesRequest,
        yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesResponse,
    ]
    """Returns a list of KPI values for tests matching the specified filter."""

class ReportServiceAsyncStub:
    """A set of methods for managing test reports."""

    GetTable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportRequest,
        yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportResponse,
    ]
    """Returns a report table for the specified test."""

    CalculateKpiValues: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesRequest,
        yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesResponse,
    ]
    """Returns a list of KPI values for tests matching the specified filter."""

class ReportServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing test reports."""

    @abc.abstractmethod
    def GetTable(
        self,
        request: yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportResponse]]:
        """Returns a report table for the specified test."""

    @abc.abstractmethod
    def CalculateKpiValues(
        self,
        request: yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesResponse]]:
        """Returns a list of KPI values for tests matching the specified filter."""

def add_ReportServiceServicer_to_server(servicer: ReportServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
