"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MaintenancePolicy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MaintenancePolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MaintenancePolicy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MAINTENANCE_POLICY_UNSPECIFIED: _MaintenancePolicy.ValueType  # 0
    RESTART: _MaintenancePolicy.ValueType  # 1
    """Restart instance to move it to another host during maintenance"""
    MIGRATE: _MaintenancePolicy.ValueType  # 2
    """Use live migration to move instance to another host during maintenance"""

class MaintenancePolicy(_MaintenancePolicy, metaclass=_MaintenancePolicyEnumTypeWrapper): ...

MAINTENANCE_POLICY_UNSPECIFIED: MaintenancePolicy.ValueType  # 0
RESTART: MaintenancePolicy.ValueType  # 1
"""Restart instance to move it to another host during maintenance"""
MIGRATE: MaintenancePolicy.ValueType  # 2
"""Use live migration to move instance to another host during maintenance"""
global___MaintenancePolicy = MaintenancePolicy
